=== modified file 'drizzled/catalog/instance.h'
--- drizzled/catalog/instance.h	2011-01-25 20:05:35 +0000
+++ drizzled/catalog/instance.h	2011-02-12 07:32:11 +0000
@@ -24,8 +24,8 @@
 #include <boost/thread/mutex.hpp>
 #include <boost/make_shared.hpp>
 
-#include "drizzled/message/catalog.h"
-#include "drizzled/identifier/session.h"
+#include <drizzled/message/catalog.h>
+#include <drizzled/identifier/session.h>
 
 namespace drizzled {
 namespace catalog {

=== modified file 'drizzled/check_stack_overrun.h'
--- drizzled/check_stack_overrun.h	2010-12-18 04:43:40 +0000
+++ drizzled/check_stack_overrun.h	2011-02-09 22:48:12 +0000
@@ -23,6 +23,8 @@
 namespace drizzled
 {
 
+class Session;
+
 /**
   @note
   Note: The 'buf' parameter is necessary, even if it is unused here.

=== added file 'drizzled/copy_field.h'
--- drizzled/copy_field.h	1970-01-01 00:00:00 +0000
+++ drizzled/copy_field.h	2011-02-12 06:56:00 +0000
@@ -0,0 +1,83 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+
+#ifndef DRIZZLED_COPY_FIELD_H
+#define DRIZZLED_COPY_FIELD_H
+
+#include <drizzled/memory/sql_alloc.h>
+#include <drizzled/sql_string.h>
+
+
+namespace drizzled {
+
+class Field;
+
+/**
+ * A class for quick copying data to fields
+ */
+class CopyField :public memory::SqlAlloc
+{
+  /**
+    Convenience definition of a copy function returned by
+    get_copy_func.
+  */
+  typedef void Copy_func(CopyField*);
+  Copy_func *get_copy_func(Field *to, Field *from);
+
+public:
+  unsigned char *from_ptr;
+  unsigned char *to_ptr;
+  unsigned char *from_null_ptr;
+  unsigned char *to_null_ptr;
+  bool *null_row;
+  uint32_t from_bit;
+  uint32_t to_bit;
+  uint32_t from_length;
+  uint32_t to_length;
+  Field *from_field;
+  Field *to_field;
+  String tmp;					// For items
+
+  CopyField() :
+    from_ptr(0),
+    to_ptr(0),
+    from_null_ptr(0),
+    to_null_ptr(0),
+    null_row(0),
+    from_bit(0),
+    to_bit(0),
+    from_length(0),
+    to_length(0),
+    from_field(0),
+    to_field(0)
+  {}
+
+  ~CopyField()
+  {}
+
+  void set(Field *to,Field *from,bool save);	// Field to field
+  void set(unsigned char *to,Field *from);		// Field to string
+  void (*do_copy)(CopyField *);
+  void (*do_copy2)(CopyField *);		// Used to handle null values
+};
+
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_COPY_FIELD_H */

=== added file 'drizzled/copy_info.h'
--- drizzled/copy_info.h	1970-01-01 00:00:00 +0000
+++ drizzled/copy_info.h	2011-02-07 22:46:08 +0000
@@ -0,0 +1,74 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Brian Aker
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_COPY_INFO_H
+#define DRIZZLED_COPY_INFO_H
+
+namespace drizzled
+{
+
+/**
+  The COPY_INFO structure is used by INSERT/REPLACE code.
+  The schema of the row counting by the INSERT/INSERT ... ON DUPLICATE KEY
+  UPDATE code:
+    If a row is inserted then the copied variable is incremented.
+    If a row is updated by the INSERT ... ON DUPLICATE KEY UPDATE and the
+      new data differs from the old one then the copied and the updated
+      variables are incremented.
+    The touched variable is incremented if a row was touched by the update part
+      of the INSERT ... ON DUPLICATE KEY UPDATE no matter whether the row
+      was actually changed or not.
+*/
+class CopyInfo 
+{
+public:
+  ha_rows records; /**< Number of processed records */
+  ha_rows deleted; /**< Number of deleted records */
+  ha_rows updated; /**< Number of updated records */
+  ha_rows copied;  /**< Number of copied records */
+  ha_rows error_count;
+  ha_rows touched; /* Number of touched records */
+  enum enum_duplicates handle_duplicates;
+  int escape_char, last_errno;
+  bool ignore;
+  /* for INSERT ... UPDATE */
+  List<Item> *update_fields;
+  List<Item> *update_values;
+  /* for VIEW ... WITH CHECK OPTION */
+
+  CopyInfo() :
+    records(0),
+    deleted(0),
+    updated(0),
+    copied(0),
+    error_count(0),
+    touched(0),
+    escape_char(0),
+    last_errno(0),
+    ignore(0),
+    update_fields(0),
+    update_values(0)
+  { }
+};
+
+
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_COPY_INFO_H */

=== modified file 'drizzled/cursor.cc'
--- drizzled/cursor.cc	2011-01-20 14:08:19 +0000
+++ drizzled/cursor.cc	2011-02-09 23:20:36 +0000
@@ -27,23 +27,24 @@
 
 #include <fcntl.h>
 
-#include "drizzled/my_hash.h"
 #include "drizzled/error.h"
+#include "drizzled/field/epoch.h"
 #include "drizzled/gettext.h"
+#include "drizzled/internal/my_sys.h"
+#include "drizzled/item/empty_string.h"
+#include "drizzled/item/int.h"
+#include "drizzled/lock.h"
+#include "drizzled/message/table.h"
+#include "drizzled/my_hash.h"
+#include "drizzled/optimizer/cost_vector.h"
+#include "drizzled/plugin/client.h"
+#include "drizzled/plugin/event_observer.h"
+#include "drizzled/plugin/storage_engine.h"
 #include "drizzled/probes.h"
-#include "drizzled/sql_parse.h"
-#include "drizzled/optimizer/cost_vector.h"
 #include "drizzled/session.h"
 #include "drizzled/sql_base.h"
+#include "drizzled/sql_parse.h"
 #include "drizzled/transaction_services.h"
-#include "drizzled/lock.h"
-#include "drizzled/item/int.h"
-#include "drizzled/item/empty_string.h"
-#include "drizzled/field/epoch.h"
-#include "drizzled/message/table.pb.h"
-#include "drizzled/plugin/client.h"
-#include "drizzled/internal/my_sys.h"
-#include "drizzled/plugin/event_observer.h"
 
 using namespace std;
 

=== modified file 'drizzled/cursor.h'
--- drizzled/cursor.h	2011-02-04 12:54:01 +0000
+++ drizzled/cursor.h	2011-02-09 22:48:12 +0000
@@ -25,18 +25,17 @@
 #include <drizzled/identifier.h>
 #include <drizzled/definitions.h>
 #include <drizzled/key_map.h>
+#include <drizzled/error_t.h>
 
 /* Definitions for parameters to do with Cursor-routines */
 
 #include <drizzled/thr_lock.h>
-#include <drizzled/sql_string.h>
 #include <drizzled/sql_list.h>
-#include <drizzled/plugin/storage_engine.h>
 #include <drizzled/handler_structs.h>
 #include <drizzled/ha_statistics.h>
 #include <drizzled/atomics.h>
 
-#include <drizzled/message/table.pb.h>
+#include <drizzled/message/table.h>
 
 #include <bitset>
 #include <algorithm>
@@ -50,24 +49,21 @@
 
 typedef std::bitset<HA_MAX_ALTER_FLAGS> HA_ALTER_FLAGS;
 
-extern uint64_t refresh_version;  /* Increments on each reload */
-
-class Table;
-class TableList;
-class TableShare;
-class Select_Lex_Unit;
+class AlterInfo;
+class CreateField;
 class ForeignKeyInfo;
-struct Order;
-
 class Item;
-
+class Item_ident;
 class LEX;
 class Select_Lex;
-class AlterInfo;
+class Select_Lex_Unit;
+class String;
+class Table;
+class TableList;
+class TableShare;
 class select_result;
-class CreateField;
 class sys_var_str;
-class Item_ident;
+struct Order;
 
 typedef List<Item> List_item;
 extern KEY_CREATE_INFO default_key_create_info;
@@ -77,10 +73,8 @@
 
 typedef struct system_status_var system_status_var;
 
-namespace optimizer
-{
-  class CostVector;
-}
+namespace optimizer { class CostVector; }
+namespace plugin { class StorageEngine; }
 
 /*
   bitmap with first N+1 bits set

=== modified file 'drizzled/db.h'
--- drizzled/db.h	2011-01-16 19:48:25 +0000
+++ drizzled/db.h	2011-02-09 22:48:12 +0000
@@ -21,9 +21,13 @@
 #ifndef DRIZZLED_DB_H
 #define DRIZZLED_DB_H
 
+#include <drizzled/message/schema.h>
+
 namespace drizzled {
 
+class Session;
 namespace message { class Schema; }
+namespace identifier { class Schema; }
 
 bool create_db(Session *session, const message::Schema &schema_message, const bool is_if_not_exists);
 bool alter_db(Session *session, const message::Schema &schema_message, const message::schema::shared_ptr &original_schema);

=== modified file 'drizzled/debug.h'
--- drizzled/debug.h	2011-01-24 05:33:52 +0000
+++ drizzled/debug.h	2011-02-09 22:48:12 +0000
@@ -21,6 +21,8 @@
 #ifndef DRIZZLED_DEBUG_H
 #define DRIZZLED_DEBUG_H
 
+#include <bitset>
+
 namespace drizzled {
 
 /* Bits from testflag */

=== modified file 'drizzled/display.cc'
--- drizzled/display.cc	2011-01-04 04:05:27 +0000
+++ drizzled/display.cc	2011-02-11 21:34:53 +0000
@@ -20,10 +20,12 @@
 
 #include "config.h"
 
-#include "drizzled/display.h"
-#include "drizzled/item.h"
+#include <drizzled/display.h>
+#include <drizzled/item.h>
 
-#include <assert.h>
+#include <cassert>
+#include <iostream>
+#include <sstream>
 
 namespace drizzled {
 namespace display {

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2011-02-11 16:10:26 +0000
+++ drizzled/drizzled.cc	2011-02-12 10:06:03 +0000
@@ -18,9 +18,10 @@
  */
 
 #include "config.h"
-#include "drizzled/configmake.h"
-#include "drizzled/atomics.h"
-#include "drizzled/data_home.h"
+
+#include <drizzled/configmake.h>
+#include <drizzled/atomics.h>
+#include <drizzled/data_home.h>
 
 #include <netdb.h>
 #include <sys/types.h>
@@ -31,7 +32,7 @@
 #include <stdexcept>
 
 #include <boost/program_options.hpp>
-#include "drizzled/program_options/config_file.h"
+#include <drizzled/program_options/config_file.h>
 #include <boost/thread/recursive_mutex.hpp>
 #include <boost/thread/mutex.hpp>
 #include <boost/thread/shared_mutex.hpp>
@@ -39,50 +40,49 @@
 #include <boost/filesystem.hpp>
 #include <boost/detail/atomic_count.hpp>
 
-#include "drizzled/internal/my_sys.h"
-#include "drizzled/internal/my_bit.h"
+#include <drizzled/cached_directory.h>
+#include <drizzled/charset.h>
+#include <drizzled/data_home.h>
+#include <drizzled/debug.h>
+#include <drizzled/definition/cache.h>
+#include <drizzled/drizzled.h>
+#include <drizzled/errmsg_print.h>
+#include <drizzled/error.h>
+#include <drizzled/global_buffer.h>
+#include <drizzled/internal/my_bit.h>
+#include <drizzled/internal/my_sys.h>
+#include <drizzled/item/cmpfunc.h>
+#include <drizzled/item/create.h>
+#include <drizzled/message/cache.h>
+#include <drizzled/module/load_list.h>
+#include <drizzled/module/registry.h>
 #include <drizzled/my_hash.h>
-#include <drizzled/error.h>
-#include <drizzled/errmsg_print.h>
-#include <drizzled/tztime.h>
+#include <drizzled/plugin/client.h>
+#include <drizzled/plugin/error_message.h>
+#include <drizzled/plugin/event_observer.h>
+#include <drizzled/plugin/listen.h>
+#include <drizzled/plugin/monitored_in_transaction.h>
+#include <drizzled/plugin/scheduler.h>
+#include <drizzled/plugin/storage_engine.h>
+#include <drizzled/plugin/xa_resource_manager.h>
+#include <drizzled/probes.h>
+#include <drizzled/replication_services.h> /* For ReplicationServices::evaluateRegisteredPlugins() */
+#include <drizzled/session.h>
+#include <drizzled/session/cache.h>
+#include <drizzled/show.h>
 #include <drizzled/sql_base.h>
-#include <drizzled/show.h>
 #include <drizzled/sql_parse.h>
-#include <drizzled/item/cmpfunc.h>
-#include <drizzled/session.h>
-#include <drizzled/item/create.h>
+#include <drizzled/temporal_format.h> /* For init_temporal_formats() */
+#include <drizzled/tztime.h>
 #include <drizzled/unireg.h>
-#include "drizzled/temporal_format.h" /* For init_temporal_formats() */
-#include "drizzled/plugin/listen.h"
-#include "drizzled/plugin/error_message.h"
-#include "drizzled/plugin/client.h"
-#include "drizzled/plugin/scheduler.h"
-#include "drizzled/plugin/xa_resource_manager.h"
-#include "drizzled/plugin/monitored_in_transaction.h"
-#include "drizzled/replication_services.h" /* For ReplicationServices::evaluateRegisteredPlugins() */
-#include "drizzled/probes.h"
-#include "drizzled/session/cache.h"
-#include "drizzled/charset.h"
-#include "plugin/myisam/myisam.h"
-#include "drizzled/drizzled.h"
-#include "drizzled/module/registry.h"
-#include "drizzled/module/load_list.h"
-#include "drizzled/global_buffer.h"
-
-#include "drizzled/debug.h"
-
-#include "drizzled/definition/cache.h"
-
-#include "drizzled/plugin/event_observer.h"
-
-#include "drizzled/data_home.h"
-
-#include "drizzled/message/cache.h"
+#include <plugin/myisam/myisam.h>
 
 #include "drizzled/visibility.h"
 
 #include <google/protobuf/stubs/common.h>
 
+#include <drizzled/refresh_version.h>
+
 #if TIME_WITH_SYS_TIME
 # include <sys/time.h>
 # include <time.h>
@@ -361,11 +361,6 @@
 
 DRIZZLED_API size_t transaction_message_threshold;
 
-/** 
-  Refresh value. We use to test this to find out if a refresh even has happened recently.
-*/
-uint64_t refresh_version;  /* Increments on each reload */
-
 /* Function declarations */
 bool drizzle_rm_tmp_tables();
 

=== modified file 'drizzled/dtcollation.h'
--- drizzled/dtcollation.h	2011-01-26 19:15:55 +0000
+++ drizzled/dtcollation.h	2011-02-11 21:34:53 +0000
@@ -27,22 +27,21 @@
 {
 
 class Item;
-typedef struct charset_info_st CHARSET_INFO;
-
+struct charset_info_st;
 
 class DRIZZLED_API DTCollation
 {
 public:
-  const CHARSET_INFO *collation;
+  const charset_info_st *collation;
   enum Derivation derivation;
 
   DRIZZLED_LOCAL DTCollation();
-  DRIZZLED_LOCAL DTCollation(const CHARSET_INFO * const collation_arg,
+  DRIZZLED_LOCAL DTCollation(const charset_info_st * const collation_arg,
                              Derivation derivation_arg);
   void set(DTCollation &dt);
-  void set(const CHARSET_INFO * const collation_arg,
+  void set(const charset_info_st * const collation_arg,
            Derivation derivation_arg);
-  void set(const CHARSET_INFO * const collation_arg);
+  void set(const charset_info_st * const collation_arg);
   void set(Derivation derivation_arg);
   bool set(DTCollation &dt1, DTCollation &dt2, uint32_t flags= 0);
 

=== modified file 'drizzled/field.h'
--- drizzled/field.h	2011-02-02 20:10:49 +0000
+++ drizzled/field.h	2011-02-12 06:56:00 +0000
@@ -34,7 +34,7 @@
 #include "drizzled/structs.h"
 #include "drizzled/charset_info.h"
 #include "drizzled/item_result.h"
-#include "drizzled/visibility.h"
+#include "drizzled/charset_info.h"
 
 #include <string>
 #include <vector>
@@ -802,55 +802,6 @@
   SendField() {}
 };
 
-/**
- * A class for quick copying data to fields
- */
-class CopyField :public memory::SqlAlloc
-{
-  /**
-    Convenience definition of a copy function returned by
-    get_copy_func.
-  */
-  typedef void Copy_func(CopyField*);
-  Copy_func *get_copy_func(Field *to, Field *from);
-
-public:
-  unsigned char *from_ptr;
-  unsigned char *to_ptr;
-  unsigned char *from_null_ptr;
-  unsigned char *to_null_ptr;
-  bool *null_row;
-  uint32_t from_bit;
-  uint32_t to_bit;
-  uint32_t from_length;
-  uint32_t to_length;
-  Field *from_field;
-  Field *to_field;
-  String tmp;					// For items
-
-  CopyField() :
-    from_ptr(0),
-    to_ptr(0),
-    from_null_ptr(0),
-    to_null_ptr(0),
-    null_row(0),
-    from_bit(0),
-    to_bit(0),
-    from_length(0),
-    to_length(0),
-    from_field(0),
-    to_field(0)
-  {}
-
-  ~CopyField()
-  {}
-
-  void set(Field *to,Field *from,bool save);	// Field to field
-  void set(unsigned char *to,Field *from);		// Field to string
-  void (*do_copy)(CopyField *);
-  void (*do_copy2)(CopyField *);		// Used to handle null values
-};
-
 uint32_t pack_length_to_packflag(uint32_t type);
 uint32_t calc_pack_length(enum_field_types type,uint32_t length);
 int set_field_to_null(Field *field);

=== modified file 'drizzled/field_conv.cc'
--- drizzled/field_conv.cc	2011-02-02 17:37:40 +0000
+++ drizzled/field_conv.cc	2011-02-12 06:56:00 +0000
@@ -25,24 +25,26 @@
 */
 
 #include "config.h"
+
 #include <drizzled/error.h>
 #include <drizzled/table.h>
 #include <drizzled/session.h>
 
-#include <drizzled/field/str.h>
-#include <drizzled/field/num.h>
+#include <drizzled/copy_field.h>
 #include <drizzled/field/blob.h>
-#include <drizzled/field/enum.h>
-#include <drizzled/field/null.h>
 #include <drizzled/field/date.h>
+#include <drizzled/field/datetime.h>
 #include <drizzled/field/decimal.h>
-#include <drizzled/field/real.h>
 #include <drizzled/field/double.h>
+#include <drizzled/field/enum.h>
+#include <drizzled/field/epoch.h>
 #include <drizzled/field/int32.h>
 #include <drizzled/field/int64.h>
-#include <drizzled/field/num.h>
-#include <drizzled/field/epoch.h>
-#include <drizzled/field/datetime.h>
+#include <drizzled/field/null.h>
+#include <drizzled/field/num.h>
+#include <drizzled/field/num.h>
+#include <drizzled/field/real.h>
+#include <drizzled/field/str.h>
 #include <drizzled/field/varstring.h>
 
 namespace drizzled

=== modified file 'drizzled/function/additive_op.cc'
--- drizzled/function/additive_op.cc	2010-12-25 00:28:49 +0000
+++ drizzled/function/additive_op.cc	2011-02-11 21:34:53 +0000
@@ -20,6 +20,7 @@
 #include "config.h"
 
 #include <drizzled/function/additive_op.h>
+#include <drizzled/type/decimal.h>
 
 #include <algorithm>
 

=== modified file 'drizzled/function/cast/boolean.cc'
--- drizzled/function/cast/boolean.cc	2011-02-02 22:22:18 +0000
+++ drizzled/function/cast/boolean.cc	2011-02-11 21:34:53 +0000
@@ -20,9 +20,10 @@
 
 #include "config.h"
 
-#include "drizzled/function/cast/boolean.h"
-#include "drizzled/type/boolean.h"
-#include "drizzled/error.h"
+#include <drizzled/error.h>
+#include <drizzled/function/cast/boolean.h>
+#include <drizzled/lex_string.h>
+#include <drizzled/type/boolean.h>
 
 namespace drizzled {
 namespace function {

=== modified file 'drizzled/function/cast/boolean.h'
--- drizzled/function/cast/boolean.h	2010-12-24 21:27:54 +0000
+++ drizzled/function/cast/boolean.h	2011-02-11 21:34:53 +0000
@@ -21,7 +21,8 @@
 #ifndef DRIZZLED_FUNCTION_CAST_BOOLEAN_H
 #define DRIZZLED_FUNCTION_CAST_BOOLEAN_H
 
-#include "drizzled/function/str/strfunc.h"
+#include <drizzled/charset_info.h>
+#include <drizzled/function/str/strfunc.h>
 
 namespace drizzled {
 namespace function {

=== modified file 'drizzled/function/cast/signed.cc'
--- drizzled/function/cast/signed.cc	2010-12-24 00:35:17 +0000
+++ drizzled/function/cast/signed.cc	2011-02-11 21:34:53 +0000
@@ -20,8 +20,10 @@
 
 #include "config.h"
 
-#include "drizzled/function/cast/signed.h"
-#include "drizzled/error.h"
+#include <drizzled/charset_info.h>
+#include <drizzled/error.h>
+#include <drizzled/function/cast/signed.h>
+#include <drizzled/lex_string.h>
 
 namespace drizzled {
 namespace function {

=== modified file 'drizzled/function/cast/unsigned.cc'
--- drizzled/function/cast/unsigned.cc	2010-12-24 00:35:17 +0000
+++ drizzled/function/cast/unsigned.cc	2011-02-11 21:34:53 +0000
@@ -20,8 +20,10 @@
 
 #include "config.h"
 
-#include "drizzled/function/cast/unsigned.h"
-#include "drizzled/error.h"
+#include <drizzled/charset_info.h>
+#include <drizzled/error.h>
+#include <drizzled/function/cast/unsigned.h>
+#include <drizzled/lex_string.h>
 
 namespace drizzled {
 namespace function {

=== modified file 'drizzled/function/find_in_set.cc'
--- drizzled/function/find_in_set.cc	2010-12-18 04:43:40 +0000
+++ drizzled/function/find_in_set.cc	2011-02-11 21:34:53 +0000
@@ -19,6 +19,7 @@
 
 #include "config.h"
 
+#include <drizzled/charset_info.h>
 #include <drizzled/function/find_in_set.h>
 
 /* Search after a string in a string of strings separated by ',' */

=== modified file 'drizzled/function/func.cc'
--- drizzled/function/func.cc	2011-01-25 05:20:15 +0000
+++ drizzled/function/func.cc	2011-02-08 03:35:42 +0000
@@ -84,7 +84,7 @@
       args= tmp_arg;
     else
     {
-      if (!(args=(Item**) session->alloc(sizeof(Item*)*arg_count)))
+      if (!(args=(Item**) session->getMemRoot()->allocate(sizeof(Item*)*arg_count)))
         return;
     }
     memcpy(args, item->args, sizeof(Item*)*arg_count);

=== modified file 'drizzled/function/func.h'
--- drizzled/function/func.h	2011-01-26 19:15:55 +0000
+++ drizzled/function/func.h	2011-02-11 21:34:53 +0000
@@ -24,10 +24,13 @@
 
 /// TODO: Rename this file - func.h is stupid.
 
+#include <drizzled/charset_info.h>
+#include <drizzled/current_session.h>
 #include <drizzled/item.h>
+#include <drizzled/item/bin_string.h>
+#include <drizzled/lex_string.h>
 #include <drizzled/sql_list.h>
-#include <drizzled/item/bin_string.h>
-#include "drizzled/current_session.h"
+#include <drizzled/type/decimal.h>
 
 #include "drizzled/visibility.h"
 

=== modified file 'drizzled/function/get_system_var.cc'
--- drizzled/function/get_system_var.cc	2010-12-30 18:34:46 +0000
+++ drizzled/function/get_system_var.cc	2011-02-09 22:48:12 +0000
@@ -22,6 +22,7 @@
 #include <drizzled/error.h>
 #include <drizzled/function/get_system_var.h>
 #include <drizzled/session.h>
+#include <drizzled/sys_var.h>
 
 namespace drizzled
 {
@@ -49,6 +50,7 @@
   */
   if (!(item= var->item(session, var_type, &component)))
     return(1);                             // Impossible
+
   item->set_name(name, 0, system_charset_info); // don't allocate a new name
   session->change_item_tree(ref, item);
 

=== modified file 'drizzled/function/get_system_var.h'
--- drizzled/function/get_system_var.h	2010-12-18 04:43:40 +0000
+++ drizzled/function/get_system_var.h	2011-02-11 21:34:53 +0000
@@ -21,10 +21,13 @@
 #define DRIZZLED_FUNCTION_GET_SYSTEM_VAR_H
 
 #include <drizzled/function/func.h>
+#include <drizzled/lex_string.h>
 
 namespace drizzled
 {
 
+class sys_var;
+
 Item *get_system_var(Session *session, sql_var_t var_type, LEX_STRING name,
                      LEX_STRING component);
 
@@ -35,6 +38,7 @@
   sys_var *var;
   sql_var_t var_type;
   LEX_STRING component;
+
 public:
   Item_func_get_system_var(sys_var *var_arg, sql_var_t var_type_arg,
                            LEX_STRING *component_arg, const char *name_arg,

=== modified file 'drizzled/function/get_user_var.h'
--- drizzled/function/get_user_var.h	2010-12-25 01:27:46 +0000
+++ drizzled/function/get_user_var.h	2011-02-11 21:34:53 +0000
@@ -21,6 +21,7 @@
 #define DRIZZLED_FUNCTION_GET_USER_VAR_H
 
 #include <drizzled/function/func.h>
+#include <drizzled/lex_string.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/function/locate.cc'
--- drizzled/function/locate.cc	2010-12-18 04:43:40 +0000
+++ drizzled/function/locate.cc	2011-02-11 21:34:53 +0000
@@ -19,7 +19,9 @@
 
 #include "config.h"
 
+#include <drizzled/charset_info.h>
 #include <drizzled/function/locate.h>
+#include <drizzled/lex_string.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/function/math/decimal_typecast.h'
--- drizzled/function/math/decimal_typecast.h	2010-12-25 01:27:46 +0000
+++ drizzled/function/math/decimal_typecast.h	2011-02-11 21:34:53 +0000
@@ -21,6 +21,7 @@
 #define DRIZZLED_FUNCTION_MATH_DECIMAL_TYPECAST_H
 
 #include <drizzled/function/func.h>
+#include <drizzled/type/decimal.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/function/math/int.cc'
--- drizzled/function/math/int.cc	2010-12-18 04:43:40 +0000
+++ drizzled/function/math/int.cc	2011-02-11 21:34:53 +0000
@@ -23,6 +23,7 @@
 
 #include <drizzled/sql_string.h>
 #include <drizzled/function/math/int.h>
+#include <drizzled/charset_info.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/function/math/int_val.cc'
--- drizzled/function/math/int_val.cc	2010-12-18 04:43:40 +0000
+++ drizzled/function/math/int_val.cc	2011-02-11 21:34:53 +0000
@@ -19,6 +19,7 @@
 
 #include "config.h"
 
+#include <drizzled/type/decimal.h>
 #include <drizzled/function/math/int_val.h>
 
 namespace drizzled

=== modified file 'drizzled/function/math/minus.cc'
--- drizzled/function/math/minus.cc	2010-12-25 01:27:46 +0000
+++ drizzled/function/math/minus.cc	2011-02-11 21:34:53 +0000
@@ -20,6 +20,7 @@
 #include "config.h"
 
 #include <drizzled/function/math/minus.h>
+#include <drizzled/type/decimal.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/function/math/mod.cc'
--- drizzled/function/math/mod.cc	2010-12-25 01:27:46 +0000
+++ drizzled/function/math/mod.cc	2011-02-11 21:34:53 +0000
@@ -20,6 +20,7 @@
 #include "config.h"
 #include <math.h>
 #include <drizzled/function/math/mod.h>
+#include <drizzled/type/decimal.h>
 
 #include <algorithm>
 

=== modified file 'drizzled/function/min_max.cc'
--- drizzled/function/min_max.cc	2011-02-04 02:14:09 +0000
+++ drizzled/function/min_max.cc	2011-02-12 08:10:17 +0000
@@ -21,6 +21,7 @@
 
 #include <drizzled/function/min_max.h>
 #include <drizzled/item/cmpfunc.h>
+#include <drizzled/session.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/function/time/typecast.h'
--- drizzled/function/time/typecast.h	2011-01-26 21:05:29 +0000
+++ drizzled/function/time/typecast.h	2011-02-11 21:34:53 +0000
@@ -20,6 +20,8 @@
 #ifndef DRIZZLED_FUNCTION_TIME_TYPECAST_H
 #define DRIZZLED_FUNCTION_TIME_TYPECAST_H
 
+#include <drizzled/charset_info.h>
+#include <drizzled/field.h>
 #include <drizzled/function/str/strfunc.h>
 #include <drizzled/temporal.h>
 

=== modified file 'drizzled/generator.h'
--- drizzled/generator.h	2010-11-19 03:03:40 +0000
+++ drizzled/generator.h	2011-02-10 22:27:27 +0000
@@ -21,16 +21,16 @@
 #ifndef DRIZZLED_GENERATOR_H
 #define DRIZZLED_GENERATOR_H
 
-#include "drizzled/session.h"
+// Needs to come first
+#include <drizzled/generator/schema.h>
+#include <drizzled/generator/all_tables.h>
 
-#include "drizzled/generator/table_definition_cache.h"
-#include "drizzled/generator/event_observers.h"
-#include "drizzled/generator/functions.h"
-#include "drizzled/generator/schema.h"
-#include "drizzled/generator/table.h"
-#include "drizzled/generator/all_tables.h"
-#include "drizzled/generator/all_fields.h"
-#include "drizzled/generator/all_indexes.h"
-#include "drizzled/generator/all_foreign_keys.h"
+#include <drizzled/generator/all_fields.h>
+#include <drizzled/generator/all_foreign_keys.h>
+#include <drizzled/generator/all_indexes.h>
+#include <drizzled/generator/event_observers.h>
+#include <drizzled/generator/functions.h>
+#include <drizzled/generator/table.h>
+#include <drizzled/generator/table_definition_cache.h>
 
 #endif /* DRIZZLED_GENERATOR_H */

=== modified file 'drizzled/generator/schema.cc'
--- drizzled/generator/schema.cc	2010-07-20 02:17:09 +0000
+++ drizzled/generator/schema.cc	2011-02-12 07:24:49 +0000
@@ -39,5 +39,43 @@
     schema_iterator= schema_names.begin();
   }
 
+Schema::operator const drizzled::message::schema::shared_ptr()
+{
+  while (schema_iterator != schema_names.end())
+  {
+    identifier::Schema schema_identifier(*schema_iterator);
+
+    if (not plugin::Authorization::isAuthorized(session.user(), schema_identifier, false))
+    {
+      schema_iterator++;
+      continue;
+    }
+
+    bool is_schema_parsed= plugin::StorageEngine::getSchemaDefinition(schema_identifier, schema);
+    schema_iterator++;
+
+    if (is_schema_parsed)
+      return schema;
+  }
+
+  return message::schema::shared_ptr();
+}
+
+Schema::operator const drizzled::identifier::Schema*()
+{
+  while (schema_iterator != schema_names.end())
+  {
+    const drizzled::identifier::Schema *_ptr= &(*schema_iterator);
+    schema_iterator++;
+
+    if (not plugin::Authorization::isAuthorized(session.user(), *_ptr, false))
+      continue;
+
+    return _ptr;
+  }
+
+  return NULL;
+}
+
 } /* namespace generator */
 } /* namespace drizzled */

=== modified file 'drizzled/generator/schema.h'
--- drizzled/generator/schema.h	2011-01-29 23:08:49 +0000
+++ drizzled/generator/schema.h	2011-02-12 07:24:49 +0000
@@ -21,11 +21,13 @@
 #ifndef DRIZZLED_GENERATOR_SCHEMA_H
 #define DRIZZLED_GENERATOR_SCHEMA_H
 
-#include <drizzled/session.h>
 #include <drizzled/plugin/authorization.h>
 #include <drizzled/plugin/storage_engine.h>
 
 namespace drizzled {
+
+class Session;
+
 namespace generator {
 
 class Schema
@@ -40,43 +42,8 @@
 
   Schema(Session &arg);
 
-  operator const drizzled::message::schema::shared_ptr()
-  {
-    while (schema_iterator != schema_names.end())
-    {
-      identifier::Schema schema_identifier(*schema_iterator);
-
-      if (not plugin::Authorization::isAuthorized(session.user(), schema_identifier, false))
-      {
-        schema_iterator++;
-        continue;
-      }
-
-      bool is_schema_parsed= plugin::StorageEngine::getSchemaDefinition(schema_identifier, schema);
-      schema_iterator++;
-
-      if (is_schema_parsed)
-        return schema;
-    }
-
-    return message::schema::shared_ptr();
-  }
-
-  operator const drizzled::identifier::Schema*()
-  {
-    while (schema_iterator != schema_names.end())
-    {
-      const drizzled::identifier::Schema *_ptr= &(*schema_iterator);
-      schema_iterator++;
-
-      if (not plugin::Authorization::isAuthorized(session.user(), *_ptr, false))
-        continue;
-
-      return _ptr;
-    }
-
-    return NULL;
-  }
+  operator const drizzled::message::schema::shared_ptr();
+  operator const drizzled::identifier::Schema*();
 };
 
 } /* namespace generator */

=== modified file 'drizzled/generator/table.h'
--- drizzled/generator/table.h	2011-01-17 04:15:23 +0000
+++ drizzled/generator/table.h	2011-02-12 08:30:55 +0000
@@ -21,10 +21,12 @@
 #ifndef DRIZZLED_GENERATOR_TABLE_H
 #define DRIZZLED_GENERATOR_TABLE_H
 
-#include "drizzled/session.h"
 #include "drizzled/plugin/storage_engine.h"
 
 namespace drizzled {
+
+class Session;
+
 namespace generator {
 
 class Table

=== modified file 'drizzled/global_charset_info.h'
--- drizzled/global_charset_info.h	2011-01-28 18:48:01 +0000
+++ drizzled/global_charset_info.h	2011-02-10 22:27:27 +0000
@@ -26,15 +26,15 @@
 namespace drizzled
 {
 
-typedef struct charset_info_st CHARSET_INFO;
+struct charset_info_st;
 
 /*
   External variables
 */
-extern DRIZZLED_API const CHARSET_INFO *default_charset_info;
-extern DRIZZLED_API const CHARSET_INFO *system_charset_info;
-extern const CHARSET_INFO *files_charset_info;
-extern const CHARSET_INFO *table_alias_charset;
+extern DRIZZLED_API const charset_info_st *default_charset_info;
+extern DRIZZLED_API const charset_info_st *system_charset_info;
+extern const charset_info_st *files_charset_info;
+extern const charset_info_st *table_alias_charset;
 
 } /* namespace drizzled */
 

=== added file 'drizzled/ha_data.h'
--- drizzled/ha_data.h	1970-01-01 00:00:00 +0000
+++ drizzled/ha_data.h	2011-02-07 23:29:10 +0000
@@ -0,0 +1,65 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Brian Aker
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_HA_DATA_H
+#define DRIZZLED_HA_DATA_H
+
+namespace drizzled
+{
+
+/**
+  Storage engine specific thread local data.
+*/
+struct Ha_data
+{
+  /**
+    Storage engine specific thread local data.
+    Lifetime: one user connection.
+  */
+  void *ha_ptr;
+  /**
+   * Resource contexts for both the "statement" and "normal"
+   * transactions.
+   *
+   * Resource context at index 0:
+   *
+   * Life time: one statement within a transaction. If @@autocommit is
+   * on, also represents the entire transaction.
+   *
+   * Resource context at index 1:
+   *
+   * Life time: one transaction within a connection. 
+   *
+   * @note
+   *
+   * If the storage engine does not participate in a transaction, 
+   * there will not be a resource context.
+   */
+  drizzled::ResourceContext resource_context[2];
+
+  Ha_data() :
+    ha_ptr(NULL)
+  {}
+};
+
+
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_HA_DATA_H */

=== modified file 'drizzled/handler_structs.h'
--- drizzled/handler_structs.h	2011-01-12 20:53:05 +0000
+++ drizzled/handler_structs.h	2011-02-10 22:27:27 +0000
@@ -32,14 +32,15 @@
 #endif
 
 #include <drizzled/base.h>
-#include <drizzled/structs.h>
 #include <drizzled/definitions.h>
 #include <drizzled/lex_string.h>
-#include "drizzled/global_charset_info.h"
+#include <drizzled/structs.h>
 
 namespace drizzled
 {
 
+struct charset_info_st;
+
 namespace plugin
 {
 class StorageEngine;
@@ -47,7 +48,7 @@
 
 typedef struct st_ha_create_information
 {
-  const CHARSET_INFO *table_charset, *default_table_charset;
+  const charset_info_st *table_charset, *default_table_charset;
   const char *alias;
   uint64_t auto_increment_value;
   uint32_t table_options;

=== modified file 'drizzled/hybrid_type_traits.cc'
--- drizzled/hybrid_type_traits.cc	2010-12-25 01:27:46 +0000
+++ drizzled/hybrid_type_traits.cc	2011-02-11 21:34:53 +0000
@@ -18,9 +18,12 @@
  */
 
 #include "config.h"
-#include "drizzled/hybrid_type_traits.h"
-#include "drizzled/hybrid_type.h"
-#include "drizzled/item.h"
+
+#include <drizzled/field.h>
+#include <drizzled/hybrid_type.h>
+#include <drizzled/hybrid_type_traits.h>
+#include <drizzled/item.h>
+
 #include <math.h>
 
 namespace drizzled

=== modified file 'drizzled/hybrid_type_traits_decimal.cc'
--- drizzled/hybrid_type_traits_decimal.cc	2011-02-04 02:14:09 +0000
+++ drizzled/hybrid_type_traits_decimal.cc	2011-02-11 21:34:53 +0000
@@ -18,10 +18,12 @@
  */
 
 #include "config.h"
-#include "drizzled/hybrid_type_traits_decimal.h"
-#include "drizzled/hybrid_type.h"
-#include "drizzled/definitions.h"
-#include "drizzled/item.h"
+
+#include <drizzled/definitions.h>
+#include <drizzled/field.h>
+#include <drizzled/hybrid_type.h>
+#include <drizzled/hybrid_type_traits_decimal.h>
+#include <drizzled/item.h>
 
 #include <algorithm>
 

=== modified file 'drizzled/hybrid_type_traits_integer.cc'
--- drizzled/hybrid_type_traits_integer.cc	2010-12-25 01:27:46 +0000
+++ drizzled/hybrid_type_traits_integer.cc	2011-02-11 21:34:53 +0000
@@ -19,10 +19,12 @@
 
 
 #include "config.h"
-#include "drizzled/hybrid_type_traits_integer.h"
-#include "drizzled/hybrid_type.h"
-#include "drizzled/definitions.h"
-#include "drizzled/item.h"
+
+#include <drizzled/definitions.h>
+#include <drizzled/field.h>
+#include <drizzled/hybrid_type.h>
+#include <drizzled/hybrid_type_traits_integer.h>
+#include <drizzled/item.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/include.am'
--- drizzled/include.am	2011-02-07 22:38:15 +0000
+++ drizzled/include.am	2011-02-12 10:06:03 +0000
@@ -64,6 +64,8 @@
 			      drizzled/common.h \
 			      drizzled/comp_creator.h \
 			      drizzled/constrained_value.h \
+			      drizzled/copy_field.h \
+			      drizzled/copy_info.h \
 			      drizzled/create_field.h \
 			      drizzled/current_session.h \
 			      drizzled/cursor.h \
@@ -214,6 +216,7 @@
 			      drizzled/gettext.h \
 			      drizzled/global_buffer.h \
 			      drizzled/global_charset_info.h \
+			      drizzled/ha_data.h \
 			      drizzled/ha_statistics.h \
 			      drizzled/handler_structs.h \
 			      drizzled/hybrid_type.h \
@@ -376,6 +379,7 @@
 			      drizzled/qsort_cmp.h \
 			      drizzled/query_id.h \
 			      drizzled/records.h \
+			      drizzled/refresh_version.h \
 			      drizzled/replication_services.h \
 			      drizzled/resource_context.h \
 			      drizzled/select_create.h \
@@ -394,6 +398,10 @@
 			      drizzled/select_union.h \
 			      drizzled/session.h \
 			      drizzled/session/cache.h \
+			      drizzled/session/property_map.h \
+			      drizzled/session/state.h \
+			      drizzled/session/table_messages.h \
+			      drizzled/session/transactions.h \
 			      drizzled/set_var.h \
 			      drizzled/show.h \
 			      drizzled/show_type.h \
@@ -459,6 +467,7 @@
 			      drizzled/structs.h \
 			      drizzled/symbol_hash.h \
 			      drizzled/sys_var.h \
+			      drizzled/system_variables.h \
 			      drizzled/table.h \
 			      drizzled/table/cache.h \
 			      drizzled/table/concurrent.h \
@@ -750,6 +759,7 @@
 			   drizzled/optimizer/access_method_factory.cc \
 			   drizzled/optimizer/explain_plan.cc \
 			   drizzled/optimizer/key_field.cc \
+			   drizzled/optimizer/position.cc \
 			   drizzled/optimizer/quick_group_min_max_select.cc \
 			   drizzled/optimizer/quick_index_merge_select.cc \
 			   drizzled/optimizer/quick_range.cc \
@@ -787,10 +797,13 @@
 			   drizzled/plugin/xa_storage_engine.cc \
 			   drizzled/query_id.cc \
 			   drizzled/records.cc \
+			   drizzled/refresh_version.cc \
 			   drizzled/replication_services.cc \
 			   drizzled/resource_context.cc \
 			   drizzled/session.cc \
 			   drizzled/session/cache.cc \
+			   drizzled/session/state.cc \
+			   drizzled/session/table_messages.cc \
 			   drizzled/set_var.cc \
 			   drizzled/show.cc \
 			   drizzled/signal_handler.cc \
@@ -852,6 +865,7 @@
 			   drizzled/statement/unlock_tables.cc \
 			   drizzled/statement/update.cc \
 			   drizzled/status_helper.cc \
+			   drizzled/stored_key.cc \
 			   drizzled/strfunc.cc \
 			   drizzled/sys_var.cc \
 			   drizzled/table.cc \

=== modified file 'drizzled/internal_error_handler.h'
--- drizzled/internal_error_handler.h	2011-01-16 20:38:08 +0000
+++ drizzled/internal_error_handler.h	2011-02-10 00:22:35 +0000
@@ -21,6 +21,8 @@
 #ifndef DRIZZLED_INTERNAL_ERROR_HANDLER_H
 #define DRIZZLED_INTERNAL_ERROR_HANDLER_H
 
+#include <drizzled/sql_error.h>
+
 namespace drizzled
 {
 

=== modified file 'drizzled/item.cc'
--- drizzled/item.cc	2011-02-07 21:08:29 +0000
+++ drizzled/item.cc	2011-02-11 21:34:53 +0000
@@ -1447,6 +1447,44 @@
   return result;
 }
 
+uint32_t Item::max_char_length() const
+{
+  return max_length / collation.collation->mbmaxlen;
+}
+
+void Item::fix_length_and_charset(uint32_t max_char_length_arg, CHARSET_INFO *cs)
+{ 
+  max_length= char_to_byte_length_safe(max_char_length_arg, cs->mbmaxlen);
+  collation.collation= cs;
+}
+
+void Item::fix_char_length(uint32_t max_char_length_arg)
+{ 
+  max_length= char_to_byte_length_safe(max_char_length_arg, collation.collation->mbmaxlen);
+}
+
+void Item::fix_char_length_uint64_t(uint64_t max_char_length_arg)
+{ 
+  uint64_t max_result_length= max_char_length_arg *
+    collation.collation->mbmaxlen;
+
+  if (max_result_length >= MAX_BLOB_WIDTH)
+  { 
+    max_length= MAX_BLOB_WIDTH;
+    maybe_null= false;
+  }
+  else
+  {
+    max_length= max_result_length;
+  }
+}
+
+void Item::fix_length_and_charset_datetime(uint32_t max_char_length_arg)
+{ 
+  collation.set(&my_charset_bin);
+  fix_char_length(max_char_length_arg);
+}
+
 Item_result item_cmp_type(Item_result a,Item_result b)
 {
   if (a == STRING_RESULT && b == STRING_RESULT)

=== modified file 'drizzled/item.h'
--- drizzled/item.h	2011-02-04 21:15:24 +0000
+++ drizzled/item.h	2011-02-11 21:34:53 +0000
@@ -22,34 +22,32 @@
 #ifndef DRIZZLED_ITEM_H
 #define DRIZZLED_ITEM_H
 
+#include <drizzled/global_charset_info.h>
 #include <drizzled/dtcollation.h>
-#include <drizzled/type/time.h>
-#include <drizzled/type/decimal.h>
 #include <drizzled/sql_list.h>
-#include "drizzled/memory/sql_alloc.h"
-#include <drizzled/table.h>
-#include "drizzled/item_result.h"
+#include <drizzled/sql_string.h>
+#include <drizzled/memory/sql_alloc.h>
+#include <drizzled/item_result.h>
 
 #include "drizzled/visibility.h"
 
 namespace drizzled
 {
 
-class TableList;
+class Field;
+class Item_equal;
 class Item_field;
-class Name_resolution_context;
+class Item_ident;
+class Item_in_subselect;
+class Item_sum;
 class Select_Lex;
-class Item_equal;
+class SendField;
+class Table;
 class user_var_entry;
-class Item_sum;
-class Item_in_subselect;
-class SendField;
-class Field;
 
-namespace plugin
-{
-class Client;
-}
+namespace plugin { class Client; }
+namespace type { class Time; }
+namespace type { class Decimal; }
 
 /**
   Dummy error processor used by default by Name_resolution_context.
@@ -793,44 +791,13 @@
     return (tmp > UINT32_MAX) ? (uint32_t) UINT32_MAX : (uint32_t) tmp;
   } 
 
-  uint32_t max_char_length() const
-  {
-    return max_length / collation.collation->mbmaxlen;
-  }
-
-  void fix_length_and_charset(uint32_t max_char_length_arg, CHARSET_INFO *cs)
-  { 
-    max_length= char_to_byte_length_safe(max_char_length_arg, cs->mbmaxlen);
-    collation.collation= cs;
-  }
-
-  void fix_char_length(uint32_t max_char_length_arg)
-  { 
-    max_length= char_to_byte_length_safe(max_char_length_arg,
-                                         collation.collation->mbmaxlen);
-  }
-
-  void fix_char_length_uint64_t(uint64_t max_char_length_arg)
-  { 
-    uint64_t max_result_length= max_char_length_arg *
-      collation.collation->mbmaxlen;
-
-    if (max_result_length >= MAX_BLOB_WIDTH)
-    { 
-      max_length= MAX_BLOB_WIDTH;
-      maybe_null= false;
-    }
-    else
-    {
-      max_length= max_result_length;
-    }
-  }
-
-  void fix_length_and_charset_datetime(uint32_t max_char_length_arg)
-  { 
-    collation.set(&my_charset_bin);
-    fix_char_length(max_char_length_arg);
-  }
+  uint32_t max_char_length() const;
+
+  void fix_length_and_charset(uint32_t max_char_length_arg, CHARSET_INFO *cs);
+  void fix_char_length(uint32_t max_char_length_arg);
+  void fix_char_length_uint64_t(uint64_t max_char_length_arg);
+  void fix_length_and_charset_datetime(uint32_t max_char_length_arg);
+
 protected:
   Session &getSession()
   {

=== modified file 'drizzled/item/bin_string.h'
--- drizzled/item/bin_string.h	2011-01-26 19:15:55 +0000
+++ drizzled/item/bin_string.h	2011-02-11 21:34:53 +0000
@@ -20,6 +20,7 @@
 #ifndef DRIZZLED_ITEM_BIN_STRING_H
 #define DRIZZLED_ITEM_BIN_STRING_H
 
+#include <drizzled/charset_info.h>
 #include <drizzled/item/hex_string.h>
 
 #include "drizzled/visibility.h"

=== modified file 'drizzled/item/cache.cc'
--- drizzled/item/cache.cc	2010-12-18 18:24:57 +0000
+++ drizzled/item/cache.cc	2011-02-11 21:34:53 +0000
@@ -19,12 +19,14 @@
 
 #include "config.h"
 
+#include <drizzled/field.h>
 #include <drizzled/item/cache.h>
-#include <drizzled/item/cache_row.h>
+#include <drizzled/item/cache_decimal.h>
 #include <drizzled/item/cache_int.h>
 #include <drizzled/item/cache_real.h>
-#include <drizzled/item/cache_decimal.h>
+#include <drizzled/item/cache_row.h>
 #include <drizzled/item/cache_str.h>
+#include <drizzled/lex_string.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/item/cache.h'
--- drizzled/item/cache.h	2010-12-18 04:43:40 +0000
+++ drizzled/item/cache.h	2011-02-11 21:34:53 +0000
@@ -20,10 +20,11 @@
 #ifndef DRIZZLED_ITEM_CACHE_H
 #define DRIZZLED_ITEM_CACHE_H
 
-#include "drizzled/item/ident.h"
-#include "drizzled/item/field.h"
-#include "drizzled/item/basic_constant.h"
-#include "drizzled/util/test.h"
+#include <drizzled/item/basic_constant.h>
+#include <drizzled/item/field.h>
+#include <drizzled/item/ident.h>
+#include <drizzled/type/decimal.h>
+#include <drizzled/util/test.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/item/cache_decimal.h'
--- drizzled/item/cache_decimal.h	2010-12-25 01:27:46 +0000
+++ drizzled/item/cache_decimal.h	2011-02-11 21:34:53 +0000
@@ -20,6 +20,7 @@
 #ifndef DRIZZLED_ITEM_CACHE_DECIMAL_H
 #define DRIZZLED_ITEM_CACHE_DECIMAL_H
 
+#include <drizzled/type/decimal.h>
 #include <drizzled/item/cache.h>
 
 namespace drizzled

=== modified file 'drizzled/item/cache_str.cc'
--- drizzled/item/cache_str.cc	2010-12-27 19:16:17 +0000
+++ drizzled/item/cache_str.cc	2011-02-11 21:34:53 +0000
@@ -20,6 +20,7 @@
 #include "config.h"
 
 #include <drizzled/item/cache_str.h>
+#include <drizzled/field.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/item/cmpfunc.cc'
--- drizzled/item/cmpfunc.cc	2011-02-08 14:47:29 +0000
+++ drizzled/item/cmpfunc.cc	2011-02-10 07:07:28 +0000
@@ -4463,9 +4463,9 @@
       {
         pattern     = first + 1;
         pattern_len = (int) len - 2;
-        int *suff = (int*) session->alloc((int) (sizeof(int)*
-                                      ((pattern_len + 1)*2+
-                                      alphabet_size)));
+        int *suff = (int*) session->getMemRoot()->allocate((int) (sizeof(int)*
+                                                                  ((pattern_len + 1)*2+
+                                                                   alphabet_size)));
         bmGs      = suff + pattern_len + 1;
         bmBc      = bmGs + pattern_len + 1;
         turboBM_compute_good_suffix_shifts(suff);

=== modified file 'drizzled/item/cmpfunc.h'
--- drizzled/item/cmpfunc.h	2011-02-04 23:02:48 +0000
+++ drizzled/item/cmpfunc.h	2011-02-12 08:10:17 +0000
@@ -31,7 +31,6 @@
 #include "drizzled/item/decimal.h"
 #include "drizzled/function/math/int.h"
 #include "drizzled/function/numhybrid.h"
-#include "drizzled/session.h"
 #include "drizzled/common.h"
 #include "drizzled/qsort_cmp.h"
 #include "drizzled/item/function/boolean.h"
@@ -40,10 +39,12 @@
 {
 
 extern Item_result item_cmp_type(Item_result a,Item_result b);
+
 class Item_bool_func2;
 class Arg_comparator;
 class Item_sum_hybrid;
 class Item_row;
+class Session;
 
 typedef int (Arg_comparator::*arg_cmp_func)();
 

=== modified file 'drizzled/item/copy_string.cc'
--- drizzled/item/copy_string.cc	2010-12-27 19:16:17 +0000
+++ drizzled/item/copy_string.cc	2011-02-11 21:34:53 +0000
@@ -19,6 +19,7 @@
 
 #include "config.h"
 
+#include <drizzled/type/decimal.h>
 #include <drizzled/item/copy_string.h>
 
 namespace drizzled

=== modified file 'drizzled/item/copy_string.h'
--- drizzled/item/copy_string.h	2010-12-25 01:27:46 +0000
+++ drizzled/item/copy_string.h	2011-02-11 21:34:53 +0000
@@ -20,8 +20,9 @@
 #ifndef DRIZZLED_ITEM_COPY_STRING_H
 #define DRIZZLED_ITEM_COPY_STRING_H
 
+#include <drizzled/charset_info.h>
+#include <drizzled/item/field.h>
 #include <drizzled/item/ident.h>
-#include <drizzled/item/field.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/item/decimal.cc'
--- drizzled/item/decimal.cc	2011-02-04 02:14:09 +0000
+++ drizzled/item/decimal.cc	2011-02-11 21:34:53 +0000
@@ -19,6 +19,8 @@
 
 #include "config.h"
 
+#include <drizzled/charset_info.h>
+#include <drizzled/field.h>
 #include <drizzled/item/decimal.h>
 
 namespace drizzled

=== modified file 'drizzled/item/field.h'
--- drizzled/item/field.h	2011-01-25 05:20:15 +0000
+++ drizzled/item/field.h	2011-02-11 21:34:53 +0000
@@ -20,11 +20,15 @@
 #ifndef DRIZZLED_ITEM_FIELD_H
 #define DRIZZLED_ITEM_FIELD_H
 
+#include <drizzled/item/ident.h>
+
 namespace drizzled
 {
 
+class COND_EQUAL;
+class Item;
+
 extern Item **not_found_item;
-class COND_EQUAL;
 
 class Item_field :public Item_ident
 {

=== modified file 'drizzled/item/float.cc'
--- drizzled/item/float.cc	2010-12-25 01:27:46 +0000
+++ drizzled/item/float.cc	2011-02-11 21:34:53 +0000
@@ -18,11 +18,14 @@
  */
 
 #include "config.h"
+
 #include <math.h>
+
 #include <drizzled/error.h>
+#include <drizzled/field.h>
+#include <drizzled/item/float.h>
 #include <drizzled/item/num.h>
 #include <drizzled/item/string.h>
-#include <drizzled/item/float.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/item/hex_string.cc'
--- drizzled/item/hex_string.cc	2010-12-25 01:27:46 +0000
+++ drizzled/item/hex_string.cc	2011-02-11 21:34:53 +0000
@@ -20,8 +20,10 @@
 #include "config.h"
 
 #include <drizzled/error.h>
+#include <drizzled/field.h>
+#include <drizzled/item/hex_string.h>
 #include <drizzled/item/string.h>
-#include <drizzled/item/hex_string.h>
+#include <drizzled/type/decimal.h>
 
 #include <algorithm>
 

=== modified file 'drizzled/item/ident.h'
--- drizzled/item/ident.h	2010-12-25 01:27:46 +0000
+++ drizzled/item/ident.h	2011-02-11 21:34:53 +0000
@@ -25,6 +25,8 @@
 namespace drizzled
 {
 
+class Name_resolution_context;
+class TableList;
 extern uint32_t lower_case_table_names;
 
 class Item_ident :public Item

=== modified file 'drizzled/item/int.cc'
--- drizzled/item/int.cc	2010-12-25 01:27:46 +0000
+++ drizzled/item/int.cc	2011-02-11 21:34:53 +0000
@@ -18,8 +18,11 @@
  */
 
 #include "config.h"
+
+#include <drizzled/charset_info.h>
+#include <drizzled/field.h>
+#include <drizzled/internal/m_string.h>
 #include <drizzled/item/int.h>
-#include "drizzled/internal/m_string.h"
 
 namespace drizzled
 {

=== modified file 'drizzled/item/null.cc'
--- drizzled/item/null.cc	2010-12-25 01:27:46 +0000
+++ drizzled/item/null.cc	2011-02-11 21:34:53 +0000
@@ -19,9 +19,10 @@
 
 #include "config.h"
 
-#include <drizzled/plugin/client.h>
+#include <drizzled/field.h>
 #include <drizzled/item/null.h>
 #include <drizzled/lex_string.h>
+#include <drizzled/plugin/client.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/item/null.h'
--- drizzled/item/null.h	2010-12-25 01:27:46 +0000
+++ drizzled/item/null.h	2011-02-11 21:34:53 +0000
@@ -20,7 +20,8 @@
 #ifndef DRIZZLED_ITEM_NULL_H
 #define DRIZZLED_ITEM_NULL_H
 
-#include "drizzled/item/basic_constant.h"
+#include <drizzled/charset_info.h>
+#include <drizzled/item/basic_constant.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/item/num.h'
--- drizzled/item/num.h	2010-12-18 04:43:40 +0000
+++ drizzled/item/num.h	2011-02-11 21:34:53 +0000
@@ -20,7 +20,8 @@
 #ifndef DRIZZLED_ITEM_NUM_H
 #define DRIZZLED_ITEM_NUM_H
 
-#include "drizzled/item/basic_constant.h"
+#include <drizzled/item/basic_constant.h>
+#include <drizzled/type/decimal.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/item/ref_null_helper.cc'
--- drizzled/item/ref_null_helper.cc	2011-01-25 05:20:15 +0000
+++ drizzled/item/ref_null_helper.cc	2011-02-11 21:34:53 +0000
@@ -18,9 +18,11 @@
  */
 
 #include "config.h"
+
 #include <drizzled/item/ref.h>
 #include <drizzled/item/ref_null_helper.h>
 #include <drizzled/item/subselect.h>
+#include <drizzled/lex_string.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/item/string.h'
--- drizzled/item/string.h	2010-12-25 01:27:46 +0000
+++ drizzled/item/string.h	2011-02-11 21:34:53 +0000
@@ -21,6 +21,7 @@
 #define DRIZZLED_ITEM_STRING_H
 
 #include <drizzled/item/basic_constant.h>
+#include <drizzled/charset_info.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/item/subselect.cc'
--- drizzled/item/subselect.cc	2011-02-04 21:42:15 +0000
+++ drizzled/item/subselect.cc	2011-02-09 22:48:12 +0000
@@ -39,6 +39,7 @@
 #include <drizzled/item/ref_null_helper.h>
 #include <drizzled/item/direct_ref.h>
 #include <drizzled/join.h>
+#include <drizzled/plugin/storage_engine.h>
 
 namespace drizzled
 {
@@ -1115,7 +1116,7 @@
 
   if (!abort_on_null && left_expr->maybe_null && !pushed_cond_guards)
   {
-    if (!(pushed_cond_guards= (bool*)join->session->alloc(sizeof(bool))))
+    if (!(pushed_cond_guards= (bool*)join->session->getMemRoot()->allocate(sizeof(bool))))
       return(RES_ERROR);
     pushed_cond_guards[0]= true;
   }
@@ -1383,7 +1384,7 @@
 
     if (!abort_on_null && left_expr->maybe_null && !pushed_cond_guards)
     {
-      if (!(pushed_cond_guards= (bool*)join->session->alloc(sizeof(bool) *
+      if (!(pushed_cond_guards= (bool*)join->session->getMemRoot()->allocate(sizeof(bool) *
                                                         left_expr->cols())))
         return(RES_ERROR);
       for (uint32_t i= 0; i < cols_num; i++)
@@ -3067,7 +3068,7 @@
     - here we initialize only those members that are used by
       subselect_uniquesubquery_engine, so these objects are incomplete.
   */
-  if (!(tab= (JoinTable*) session->alloc(sizeof(JoinTable))))
+  if (!(tab= (JoinTable*) session->getMemRoot()->allocate(sizeof(JoinTable))))
     return(true);
   new (tab) JoinTable();
   tab->table= tmp_table;
@@ -3076,10 +3077,10 @@
   if (!(tab->ref.key_buff=
         (unsigned char*) session->calloc(ALIGN_SIZE(tmp_key->key_length) * 2)) ||
       !(tab->ref.key_copy=
-        (StoredKey**) session->alloc((sizeof(StoredKey*) *
+        (StoredKey**) session->getMemRoot()->allocate((sizeof(StoredKey*) *
                                   (tmp_key_parts + 1)))) ||
       !(tab->ref.items=
-        (Item**) session->alloc(sizeof(Item*) * tmp_key_parts)))
+        (Item**) session->getMemRoot()->allocate(sizeof(Item*) * tmp_key_parts)))
     return(true);
 
   KeyPartInfo *cur_key_part= tmp_key->key_part;

=== modified file 'drizzled/item/sum.cc'
--- drizzled/item/sum.cc	2011-02-04 21:15:24 +0000
+++ drizzled/item/sum.cc	2011-02-08 03:35:42 +0000
@@ -412,7 +412,7 @@
   if (arg_count <= 2)
     args=tmp_args;
   else
-    if (!(args= (Item**) session->alloc(sizeof(Item*)*arg_count)))
+    if (!(args= (Item**) session->getMemRoot()->allocate(sizeof(Item*)*arg_count)))
       return;
   memcpy(args, item->args, sizeof(Item*)*arg_count);
 }
@@ -2667,7 +2667,7 @@
         uint32_t *length;
         compare_key= (qsort_cmp2) composite_key_cmp;
         cmp_arg= (void*) this;
-        field_lengths= (uint32_t*) session->alloc(table->getShare()->sizeFields() * sizeof(uint32_t));
+        field_lengths= (uint32_t*) session->getMemRoot()->allocate(table->getShare()->sizeFields() * sizeof(uint32_t));
         for (tree_key_length= 0, length= field_lengths, field= table->getFields();
              field < field_end; ++field, ++length)
         {

=== modified file 'drizzled/item/sum.h'
--- drizzled/item/sum.h	2010-12-25 01:27:46 +0000
+++ drizzled/item/sum.h	2011-02-11 21:34:53 +0000
@@ -22,12 +22,12 @@
 
 /* classes for sum functions */
 
-
 #include "drizzled/tree.h"
 #include <drizzled/hybrid_type.h>
 #include <drizzled/item.h>
 #include <drizzled/item/field.h>
 #include <drizzled/item/bin_string.h>
+#include <drizzled/charset_info.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/item/uint.cc'
--- drizzled/item/uint.cc	2010-12-18 04:43:40 +0000
+++ drizzled/item/uint.cc	2011-02-11 21:34:53 +0000
@@ -18,6 +18,8 @@
  */
 
 #include "config.h"
+
+#include <drizzled/charset_info.h>
 #include <drizzled/item/uint.h>
 
 namespace drizzled

=== modified file 'drizzled/join.cc'
--- drizzled/join.cc	2011-02-07 17:20:59 +0000
+++ drizzled/join.cc	2011-02-12 02:52:14 +0000
@@ -58,6 +58,7 @@
 #include "drizzled/internal/my_bit.h"
 #include "drizzled/internal/my_sys.h"
 #include "drizzled/internal/iocache.h"
+#include "drizzled/plugin/storage_engine.h"
 
 #include <drizzled/debug.h>
 
@@ -133,6 +134,184 @@
 static bool add_ref_to_table_cond(Session *session, JoinTable *join_tab);
 static void free_blobs(Field **ptr); /* Rename this method...conflicts with another in global namespace... */
 
+Join::Join(Session *session_arg, 
+           List<Item> &fields_arg, 
+           uint64_t select_options_arg,
+           select_result *result_arg) :
+  join_tab(NULL),
+  best_ref(NULL),
+  map2table(NULL),
+  join_tab_save(NULL),
+  table(NULL),
+  all_tables(NULL),
+  sort_by_table(NULL),
+  tables(0),
+  outer_tables(0),
+  const_tables(0),
+  send_group_parts(0),
+  sort_and_group(false),
+  first_record(false),
+  full_join(false),
+  group(false),
+  no_field_update(false),
+  do_send_rows(true),
+  resume_nested_loop(false),
+  no_const_tables(false),
+  select_distinct(false),
+  group_optimized_away(false),
+  simple_order(false),
+  simple_group(false),
+  no_order(false),
+  skip_sort_order(false),
+  union_part(false),
+  optimized(false),
+  need_tmp(false),
+  hidden_group_fields(false),
+  const_table_map(0),
+  found_const_table_map(0),
+  outer_join(0),
+  send_records(0),
+  found_records(0),
+  examined_rows(0),
+  row_limit(0),
+  select_limit(0),
+  fetch_limit(HA_POS_ERROR),
+  session(session_arg),
+  fields_list(fields_arg), 
+  join_list(NULL),
+  unit(NULL),
+  select_lex(NULL),
+  select(NULL),
+  exec_tmp_table1(NULL),
+  exec_tmp_table2(NULL),
+  sum_funcs(NULL),
+  sum_funcs2(NULL),
+  having(NULL),
+  tmp_having(NULL),
+  having_history(NULL),
+  select_options(select_options_arg),
+  result(result_arg),
+  lock(session_arg->lock),
+  tmp_join(NULL),
+  all_fields(fields_arg),
+  error(0),
+  cond_equal(NULL),
+  return_tab(NULL),
+  ref_pointer_array(NULL),
+  items0(NULL),
+  items1(NULL),
+  items2(NULL),
+  items3(NULL),
+  ref_pointer_array_size(0),
+  zero_result_cause(NULL),
+  sortorder(NULL),
+  table_reexec(NULL),
+  join_tab_reexec(NULL)
+{
+  select_distinct= test(select_options & SELECT_DISTINCT);
+  if (&fields_list != &fields_arg) /* only copy if not same*/
+    fields_list= fields_arg;
+  memset(&keyuse, 0, sizeof(keyuse));
+  tmp_table_param.init();
+  tmp_table_param.end_write_records= HA_POS_ERROR;
+  rollup.setState(Rollup::STATE_NONE);
+}
+
+  /** 
+   * This method is currently only used when a subselect EXPLAIN is performed.
+   * I pulled out the init() method and have simply reset the values to what
+   * was previously in the init() method.  See the note about the hack in 
+   * sql_union.cc...
+   */
+void Join::reset(Session *session_arg, 
+                 List<Item> &fields_arg, 
+                 uint64_t select_options_arg,
+                 select_result *result_arg)
+{
+  join_tab= NULL;
+  best_ref= NULL;
+  map2table= NULL;
+  join_tab_save= NULL;
+  table= NULL;
+  all_tables= NULL;
+  sort_by_table= NULL;
+  tables= 0;
+  outer_tables= 0;
+  const_tables= 0;
+  send_group_parts= 0;
+  sort_and_group= false;
+  first_record= false;
+  full_join= false;
+  group= false;
+  no_field_update= false;
+  do_send_rows= true;
+  resume_nested_loop= false;
+  no_const_tables= false;
+  select_distinct= false;
+  group_optimized_away= false;
+  simple_order= false;
+  simple_group= false;
+  no_order= false;
+  skip_sort_order= false;
+  union_part= false;
+  optimized= false;
+  need_tmp= false;
+  hidden_group_fields= false;
+  const_table_map= 0;
+  found_const_table_map= 0;
+  outer_join= 0;
+  send_records= 0;
+  found_records= 0;
+  examined_rows= 0;
+  row_limit= 0;
+  select_limit= 0;
+  fetch_limit= HA_POS_ERROR;
+  session= session_arg;
+  fields_list= fields_arg; 
+  join_list= NULL;
+  unit= NULL;
+  select_lex= NULL;
+  select= NULL;
+  exec_tmp_table1= NULL;
+  exec_tmp_table2= NULL;
+  sum_funcs= NULL;
+  sum_funcs2= NULL;
+  having= NULL;
+  tmp_having= NULL;
+  having_history= NULL;
+  select_options= select_options_arg;
+  result= result_arg;
+  lock= session_arg->lock;
+  tmp_join= NULL;
+  all_fields= fields_arg;
+  error= 0;
+  cond_equal= NULL;
+  return_tab= NULL;
+  ref_pointer_array= NULL;
+  items0= NULL;
+  items1= NULL;
+  items2= NULL;
+  items3= NULL;
+  ref_pointer_array_size= 0;
+  zero_result_cause= NULL;
+  sortorder= NULL;
+  table_reexec= NULL;
+  join_tab_reexec= NULL;
+  select_distinct= test(select_options & SELECT_DISTINCT);
+  if (&fields_list != &fields_arg) /* only copy if not same*/
+    fields_list= fields_arg;
+  memset(&keyuse, 0, sizeof(keyuse));
+  tmp_table_param.init();
+  tmp_table_param.end_write_records= HA_POS_ERROR;
+  rollup.setState(Rollup::STATE_NONE);
+}
+
+bool Join::is_top_level_join() const
+{
+  return (unit == &session->lex->unit && (unit->fake_select_lex == 0 ||
+                                          select_lex == unit->fake_select_lex));
+}
+
 /**
   Prepare of whole select (including sub queries in future).
 
@@ -1171,7 +1350,7 @@
 */
 bool Join::init_save_join_tab()
 {
-  if (!(tmp_join= (Join*)session->alloc(sizeof(Join))))
+  if (!(tmp_join= (Join*)session->getMemRoot()->allocate(sizeof(Join))))
     return 1;
 
   error= 0;              // Ensure that tmp_join.error= 0
@@ -1184,7 +1363,7 @@
 {
   if (! join_tab_save && select_lex->master_unit()->uncacheable.any())
   {
-    if (!(join_tab_save= (JoinTable*)session->memdup((unsigned char*) join_tab,
+    if (!(join_tab_save= (JoinTable*)session->getMemRoot()->duplicate((unsigned char*) join_tab,
             sizeof(JoinTable) * tables)))
       return 1;
   }
@@ -2078,7 +2257,7 @@
   */
   tmp_table_param.group_parts= send_group_parts;
 
-  rollup.setNullItems((Item_null_result**) session->alloc((sizeof(Item*) +
+  rollup.setNullItems((Item_null_result**) session->getMemRoot()->allocate((sizeof(Item*) +
                                                                 sizeof(Item**) +
                                                                 sizeof(List<Item>) +
                                                                 ref_pointer_array_size)
@@ -3226,7 +3405,7 @@
 
   table_count=join->tables;
   if (!(join->join_tab=join_tab=
-  (JoinTable*) session->alloc(sizeof(JoinTable)*table_count)))
+  (JoinTable*) session->getMemRoot()->allocate(sizeof(JoinTable)*table_count)))
     return(true);
 
   for (i= 0; i < table_count; i++)
@@ -4384,7 +4563,7 @@
   */
   if (!join->table_reexec)
   {
-    if (!(join->table_reexec= (Table**) join->session->alloc(sizeof(Table*))))
+    if (!(join->table_reexec= (Table**) join->session->getMemRoot()->allocate(sizeof(Table*))))
       return(true);
     if (join->tmp_join)
       join->tmp_join->table_reexec= join->table_reexec;
@@ -4392,7 +4571,7 @@
   if (!join->join_tab_reexec)
   {
     if (!(join->join_tab_reexec=
-          (JoinTable*) join->session->alloc(sizeof(JoinTable))))
+          (JoinTable*) join->session->getMemRoot()->allocate(sizeof(JoinTable))))
       return(true);
     new (join->join_tab_reexec) JoinTable();
     if (join->tmp_join)
@@ -4659,7 +4838,7 @@
           tab->type == AM_EQ_REF)
       {
         optimizer::SqlSelect *sel= tab->select= ((optimizer::SqlSelect*)
-            session->memdup((unsigned char*) select,
+            session->getMemRoot()->duplicate((unsigned char*) select,
               sizeof(*select)));
         if (! sel)
           return 1;			// End of memory
@@ -4797,7 +4976,7 @@
                                          current_map, 0)))
             {
               tab->cache.select= (optimizer::SqlSelect*)
-                session->memdup((unsigned char*) sel, sizeof(optimizer::SqlSelect));
+                session->getMemRoot()->duplicate((unsigned char*) sel, sizeof(optimizer::SqlSelect));
               tab->cache.select->cond= tmp;
               tab->cache.select->read_tables= join->const_table_map;
             }
@@ -4933,7 +5112,7 @@
 
     if (tab->insideout_match_tab)
     {
-      if (! (tab->insideout_buf= (unsigned char*) join->session->alloc(tab->table->key_info
+      if (! (tab->insideout_buf= (unsigned char*) join->session->getMemRoot()->allocate(tab->table->key_info
                                                                        [tab->index].
                                                                        key_length)))
         return true;
@@ -5524,8 +5703,8 @@
 
   table_count= join->tables;
   stat= (JoinTable*) join->session->calloc(sizeof(JoinTable)*table_count);
-  stat_ref= (JoinTable**) join->session->alloc(sizeof(JoinTable*)*MAX_TABLES);
-  table_vector= (Table**) join->session->alloc(sizeof(Table*)*(table_count*2));
+  stat_ref= (JoinTable**) join->session->getMemRoot()->allocate(sizeof(JoinTable*)*MAX_TABLES);
+  table_vector= (Table**) join->session->getMemRoot()->allocate(sizeof(Table*)*(table_count*2));
   if (! stat || ! stat_ref || ! table_vector)
     return 1;
 

=== modified file 'drizzled/join.h'
--- drizzled/join.h	2011-01-17 07:58:22 +0000
+++ drizzled/join.h	2011-02-12 06:13:32 +0000
@@ -28,12 +28,15 @@
 #define DRIZZLED_JOIN_H
 
 #include <drizzled/optimizer/position.h>
-#include "drizzled/sql_select.h"
+#include <drizzled/session.h>
+#include <drizzled/sql_select.h>
 #include <bitset>
 
 namespace drizzled
 {
 
+class Session;
+
 class Join :public memory::SqlAlloc
 {
   Join(const Join &rhs);                        /**< not implemented */
@@ -228,86 +231,7 @@
   Join(Session *session_arg, 
        List<Item> &fields_arg, 
        uint64_t select_options_arg,
-       select_result *result_arg)
-    :
-      join_tab(NULL),
-      best_ref(NULL),
-      map2table(NULL),
-      join_tab_save(NULL),
-      table(NULL),
-      all_tables(NULL),
-      sort_by_table(NULL),
-      tables(0),
-      outer_tables(0),
-      const_tables(0),
-      send_group_parts(0),
-      sort_and_group(false),
-      first_record(false),
-      full_join(false),
-      group(false),
-      no_field_update(false),
-      do_send_rows(true),
-      resume_nested_loop(false),
-      no_const_tables(false),
-      select_distinct(false),
-      group_optimized_away(false),
-      simple_order(false),
-      simple_group(false),
-      no_order(false),
-      skip_sort_order(false),
-      union_part(false),
-      optimized(false),
-      need_tmp(false),
-      hidden_group_fields(false),
-      const_table_map(0),
-      found_const_table_map(0),
-      outer_join(0),
-      send_records(0),
-      found_records(0),
-      examined_rows(0),
-      row_limit(0),
-      select_limit(0),
-      fetch_limit(HA_POS_ERROR),
-      session(session_arg),
-      fields_list(fields_arg), 
-      join_list(NULL),
-      unit(NULL),
-      select_lex(NULL),
-      select(NULL),
-      exec_tmp_table1(NULL),
-      exec_tmp_table2(NULL),
-      sum_funcs(NULL),
-      sum_funcs2(NULL),
-      having(NULL),
-      tmp_having(NULL),
-      having_history(NULL),
-      select_options(select_options_arg),
-      result(result_arg),
-      lock(session_arg->lock),
-      tmp_join(NULL),
-      all_fields(fields_arg),
-      error(0),
-      cond_equal(NULL),
-      return_tab(NULL),
-      ref_pointer_array(NULL),
-      items0(NULL),
-      items1(NULL),
-      items2(NULL),
-      items3(NULL),
-      ref_pointer_array_size(0),
-      zero_result_cause(NULL),
-      sortorder(NULL),
-      table_reexec(NULL),
-      join_tab_reexec(NULL)
-  {
-    select_distinct= test(select_options & SELECT_DISTINCT);
-    if (&fields_list != &fields_arg) /* only copy if not same*/
-      fields_list= fields_arg;
-    memset(&keyuse, 0, sizeof(keyuse));
-    tmp_table_param.init();
-    tmp_table_param.end_write_records= HA_POS_ERROR;
-    rollup.setState(Rollup::STATE_NONE);
-  }
+       select_result *result_arg);
 
   /** 
    * This method is currently only used when a subselect EXPLAIN is performed.
@@ -315,88 +239,10 @@
    * was previously in the init() method.  See the note about the hack in 
    * sql_union.cc...
    */
-  inline void reset(Session *session_arg, 
-       List<Item> &fields_arg, 
-       uint64_t select_options_arg,
-       select_result *result_arg)
-  {
-    join_tab= NULL;
-    best_ref= NULL;
-    map2table= NULL;
-    join_tab_save= NULL;
-    table= NULL;
-    all_tables= NULL;
-    sort_by_table= NULL;
-    tables= 0;
-    outer_tables= 0;
-    const_tables= 0;
-    send_group_parts= 0;
-    sort_and_group= false;
-    first_record= false;
-    full_join= false;
-    group= false;
-    no_field_update= false;
-    do_send_rows= true;
-    resume_nested_loop= false;
-    no_const_tables= false;
-    select_distinct= false;
-    group_optimized_away= false;
-    simple_order= false;
-    simple_group= false;
-    no_order= false;
-    skip_sort_order= false;
-    union_part= false;
-    optimized= false;
-    need_tmp= false;
-    hidden_group_fields= false;
-    const_table_map= 0;
-    found_const_table_map= 0;
-    outer_join= 0;
-    send_records= 0;
-    found_records= 0;
-    examined_rows= 0;
-    row_limit= 0;
-    select_limit= 0;
-    fetch_limit= HA_POS_ERROR;
-    session= session_arg;
-    fields_list= fields_arg; 
-    join_list= NULL;
-    unit= NULL;
-    select_lex= NULL;
-    select= NULL;
-    exec_tmp_table1= NULL;
-    exec_tmp_table2= NULL;
-    sum_funcs= NULL;
-    sum_funcs2= NULL;
-    having= NULL;
-    tmp_having= NULL;
-    having_history= NULL;
-    select_options= select_options_arg;
-    result= result_arg;
-    lock= session_arg->lock;
-    tmp_join= NULL;
-    all_fields= fields_arg;
-    error= 0;
-    cond_equal= NULL;
-    return_tab= NULL;
-    ref_pointer_array= NULL;
-    items0= NULL;
-    items1= NULL;
-    items2= NULL;
-    items3= NULL;
-    ref_pointer_array_size= 0;
-    zero_result_cause= NULL;
-    sortorder= NULL;
-    table_reexec= NULL;
-    join_tab_reexec= NULL;
-    select_distinct= test(select_options & SELECT_DISTINCT);
-    if (&fields_list != &fields_arg) /* only copy if not same*/
-      fields_list= fields_arg;
-    memset(&keyuse, 0, sizeof(keyuse));
-    tmp_table_param.init();
-    tmp_table_param.end_write_records= HA_POS_ERROR;
-    rollup.setState(Rollup::STATE_NONE);
-  }
+  void reset(Session *session_arg, 
+             List<Item> &fields_arg, 
+             uint64_t select_options_arg,
+             select_result *result_arg);
 
   int prepare(Item ***rref_pointer_array, 
               TableList *tables,
@@ -408,6 +254,7 @@
               Item *having,
               Select_Lex *select,
               Select_Lex_Unit *unit);
+
   int optimize();
   int reinit();
   void exec();
@@ -457,11 +304,7 @@
 	    !group_list);
   }
   bool change_result(select_result *result);
-  bool is_top_level_join() const
-  {
-    return (unit == &session->lex->unit && (unit->fake_select_lex == 0 ||
-                                        select_lex == unit->fake_select_lex));
-  }
+  bool is_top_level_join() const;
 
   /**
    * Copy the partial query plan into the optimal query plan.

=== modified file 'drizzled/key.cc'
--- drizzled/key.cc	2010-12-16 02:16:37 +0000
+++ drizzled/key.cc	2011-02-09 22:48:12 +0000
@@ -21,6 +21,7 @@
 #include "drizzled/key.h"
 #include "drizzled/field/blob.h"
 #include "drizzled/util/test.h"
+#include "drizzled/plugin/storage_engine.h"
 
 #include <boost/dynamic_bitset.hpp>
 
@@ -329,7 +330,7 @@
      idx	Key number
 */
 
-void key_unpack(String *to, Table *table, uint32_t idx)
+void key_unpack(String *to, const Table *table, uint32_t idx)
 {
   KeyPartInfo *key_part,*key_part_end;
   Field *field;

=== modified file 'drizzled/key.h'
--- drizzled/key.h	2011-01-26 19:15:55 +0000
+++ drizzled/key.h	2011-02-09 22:48:12 +0000
@@ -103,7 +103,7 @@
                  uint16_t key_length);
 void key_zero_nulls(unsigned char *tuple, KeyInfo *key_info);
 bool key_cmp_if_same(Table *form,const unsigned char *key,uint32_t index,uint32_t key_length);
-void key_unpack(String *to,Table *form,uint32_t index);
+void key_unpack(String *to, const Table *form,uint32_t index);
 bool is_key_used(Table *table, uint32_t idx, const boost::dynamic_bitset<>& fields);
 int key_cmp(KeyPartInfo *key_part, const unsigned char *key, uint32_t key_length);
 

=== modified file 'drizzled/locking/global.cc'
--- drizzled/locking/global.cc	2011-01-18 00:26:36 +0000
+++ drizzled/locking/global.cc	2011-02-09 22:48:12 +0000
@@ -77,16 +77,20 @@
   we are forced to use mysql_lock_merge.
 */
 #include "config.h"
+
 #include <fcntl.h>
+
 #include <drizzled/error.h>
 #include <drizzled/my_hash.h>
 #include <drizzled/thr_lock.h>
 #include <drizzled/session.h>
 #include <drizzled/sql_base.h>
 #include <drizzled/lock.h>
-#include "drizzled/pthread_globals.h"
-#include "drizzled/internal/my_sys.h"
-#include "drizzled/pthread_globals.h"
+#include <drizzled/pthread_globals.h>
+#include <drizzled/internal/my_sys.h>
+#include <drizzled/pthread_globals.h>
+#include <drizzled/refresh_version.h>
+#include <drizzled/plugin/storage_engine.h>
 
 #include <set>
 #include <vector>

=== modified file 'drizzled/main.cc'
--- drizzled/main.cc	2011-02-10 23:40:41 +0000
+++ drizzled/main.cc	2011-02-12 10:06:03 +0000
@@ -44,29 +44,28 @@
 
 #include <boost/filesystem.hpp>
 
-#include "drizzled/plugin.h"
-#include "drizzled/gettext.h"
-#include "drizzled/configmake.h"
-#include "drizzled/session.h"
-#include "drizzled/session/cache.h"
-#include "drizzled/internal/my_sys.h"
-#include "drizzled/unireg.h"
-#include "drizzled/drizzled.h"
-#include "drizzled/errmsg_print.h"
-#include "drizzled/data_home.h"
-#include "drizzled/plugin/listen.h"
-#include "drizzled/plugin/client.h"
-#include "drizzled/pthread_globals.h"
-#include "drizzled/tztime.h"
-#include "drizzled/signal_handler.h"
-#include "drizzled/replication_services.h"
-#include "drizzled/transaction_services.h"
-#include "drizzled/catalog/local.h"
-#include "drizzled/abort_exception.h"
-
+#include <drizzled/abort_exception.h>
+#include <drizzled/catalog/local.h>
+#include <drizzled/configmake.h>
+#include <drizzled/data_home.h>
 #include <drizzled/debug.h>
-
-#include "drizzled/util/backtrace.h"
+#include <drizzled/drizzled.h>
+#include <drizzled/errmsg_print.h>
+#include <drizzled/gettext.h>
+#include <drizzled/internal/my_sys.h>
+#include <drizzled/plugin.h>
+#include <drizzled/plugin/client.h>
+#include <drizzled/plugin/listen.h>
+#include <drizzled/plugin/monitored_in_transaction.h>
+#include <drizzled/pthread_globals.h>
+#include <drizzled/replication_services.h>
+#include <drizzled/session.h>
+#include <drizzled/session/cache.h>
+#include <drizzled/signal_handler.h>
+#include <drizzled/transaction_services.h>
+#include <drizzled/tztime.h>
+#include <drizzled/unireg.h>
+#include <drizzled/util/backtrace.h>
 
 extern "C" int daemonize(int nochdir, int noclose, int wait_sigusr1);
 extern "C" int daemon_is_ready(void);

=== modified file 'drizzled/memory/root.h'
--- drizzled/memory/root.h	2011-01-26 19:15:55 +0000
+++ drizzled/memory/root.h	2011-02-08 04:55:48 +0000
@@ -123,12 +123,22 @@
   void (*error_handler)(void);
   void reset_root_defaults(size_t block_size, size_t prealloc_size);
   void *alloc_root(size_t Size);
+  inline void *allocate(size_t Size)
+  {
+    return alloc_root(Size);
+  }
   void mark_blocks_free();
   void *memdup_root(const void *str, size_t len);
   char *strdup_root(const char *str);
+
   char *strmake_root(const char *str,size_t len);
   void init_alloc_root(size_t block_size= ROOT_MIN_BLOCK_SIZE);
 
+  inline void *duplicate(const void *str, size_t len)
+  {
+    return memdup_root(str, len);
+  }
+
   inline bool alloc_root_inited()
   {
     return min_malloc != 0;

=== modified file 'drizzled/nested_join.h'
--- drizzled/nested_join.h	2011-02-04 19:50:47 +0000
+++ drizzled/nested_join.h	2011-02-11 21:34:53 +0000
@@ -20,14 +20,16 @@
 #ifndef DRIZZLED_NESTED_JOIN_H
 #define DRIZZLED_NESTED_JOIN_H
 
+#include <drizzled/item.h>
+#include <drizzled/lex_string.h>
 #include <drizzled/sql_list.h>
-#include <drizzled/item.h>
 
 #include <bitset>
 
 namespace drizzled
 {
 class TableList;
+class JoinTable;
 
 class NestedJoin
 {

=== modified file 'drizzled/open_tables_state.h'
--- drizzled/open_tables_state.h	2011-01-17 04:15:23 +0000
+++ drizzled/open_tables_state.h	2011-02-10 00:22:35 +0000
@@ -22,10 +22,13 @@
 #define DRIZZLED_OPEN_TABLES_STATE_H
 
 #include "drizzled/lock.h"
+#include "drizzled/query_id.h"
 
 namespace drizzled
 {
 
+class CachedDirectory;
+
 /**
   Class that holds information about tables which were opened and locked
   by the thread. It is also used to save/restore this information in

=== added file 'drizzled/optimizer/position.cc'
--- drizzled/optimizer/position.cc	1970-01-01 00:00:00 +0000
+++ drizzled/optimizer/position.cc	2011-02-12 08:20:19 +0000
@@ -0,0 +1,41 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include <drizzled/optimizer/position.h>
+#include <drizzled/table.h>
+
+namespace drizzled
+{
+namespace optimizer
+{
+
+bool Position::examinePosition(table_map found_ref)
+{
+  if (table->table->map & found_ref)
+  {
+    return true;
+  }
+  return false;
+}
+
+} /* end namespace optimizer */
+
+} /* end namespace drizzled */

=== modified file 'drizzled/optimizer/position.h'
--- drizzled/optimizer/position.h	2011-02-04 18:26:39 +0000
+++ drizzled/optimizer/position.h	2011-02-12 08:20:19 +0000
@@ -20,7 +20,7 @@
 #ifndef DRIZZLED_OPTIMIZER_POSITION_H
 #define DRIZZLED_OPTIMIZER_POSITION_H
 
-#include "drizzled/join_table.h"
+#include <drizzled/join_table.h>
 
 namespace drizzled
 {
@@ -131,14 +131,7 @@
     return (cmp_table != table->table);
   }
 
-  bool examinePosition(table_map found_ref)
-  {
-    if (table->table->map & found_ref)
-    {
-      return true;
-    }
-    return false;
-  }
+  bool examinePosition(table_map found_ref);
 
   KeyUse *getKeyUse()
   {

=== modified file 'drizzled/optimizer/quick_index_merge_select.h'
--- drizzled/optimizer/quick_index_merge_select.h	2010-12-18 04:43:40 +0000
+++ drizzled/optimizer/quick_index_merge_select.h	2011-02-09 22:48:12 +0000
@@ -20,7 +20,8 @@
 #ifndef DRIZZLED_OPTIMIZER_QUICK_INDEX_MERGE_SELECT_H
 #define DRIZZLED_OPTIMIZER_QUICK_INDEX_MERGE_SELECT_H
 
-#include "drizzled/optimizer/range.h"
+#include <drizzled/optimizer/range.h>
+#include <drizzled/records.h>
 
 #include <boost/dynamic_bitset.hpp>
 #include <vector>

=== modified file 'drizzled/optimizer/range.cc'
--- drizzled/optimizer/range.cc	2011-02-08 15:18:13 +0000
+++ drizzled/optimizer/range.cc	2011-02-10 07:07:28 +0000
@@ -111,29 +111,31 @@
 
 #include <boost/dynamic_bitset.hpp>
 
-#include "drizzled/sql_base.h"
-#include "drizzled/sql_select.h"
+#include "drizzled/check_stack_overrun.h"
 #include "drizzled/error.h"
+#include "drizzled/field/num.h"
+#include "drizzled/internal/iocache.h"
+#include "drizzled/internal/my_sys.h"
+#include "drizzled/item/cmpfunc.h"
 #include "drizzled/optimizer/cost_vector.h"
-#include "drizzled/item/cmpfunc.h"
-#include "drizzled/field/num.h"
-#include "drizzled/check_stack_overrun.h"
-#include "drizzled/optimizer/sum.h"
-#include "drizzled/optimizer/range.h"
+#include "drizzled/optimizer/quick_group_min_max_select.h"
+#include "drizzled/optimizer/quick_index_merge_select.h"
 #include "drizzled/optimizer/quick_range.h"
 #include "drizzled/optimizer/quick_range_select.h"
-#include "drizzled/optimizer/quick_group_min_max_select.h"
-#include "drizzled/optimizer/quick_index_merge_select.h"
 #include "drizzled/optimizer/quick_ror_intersect_select.h"
 #include "drizzled/optimizer/quick_ror_union_select.h"
-#include "drizzled/optimizer/table_read_plan.h"
+#include "drizzled/optimizer/range.h"
+#include "drizzled/optimizer/range_param.h"
 #include "drizzled/optimizer/sel_arg.h"
 #include "drizzled/optimizer/sel_imerge.h"
 #include "drizzled/optimizer/sel_tree.h"
-#include "drizzled/optimizer/range_param.h"
+#include "drizzled/optimizer/sum.h"
+#include "drizzled/optimizer/table_read_plan.h"
+#include "drizzled/plugin/storage_engine.h"
 #include "drizzled/records.h"
-#include "drizzled/internal/my_sys.h"
-#include "drizzled/internal/iocache.h"
+#include "drizzled/sql_base.h"
+#include "drizzled/sql_select.h"
+#include "drizzled/table_reference.h"
 
 #include "drizzled/temporal.h" /* Needed in get_mm_leaf() for timestamp -> datetime comparisons */
 

=== modified file 'drizzled/optimizer/range.h'
--- drizzled/optimizer/range.h	2010-12-18 04:43:40 +0000
+++ drizzled/optimizer/range.h	2011-02-11 21:34:53 +0000
@@ -22,11 +22,14 @@
 #ifndef DRIZZLED_OPTIMIZER_RANGE_H
 #define DRIZZLED_OPTIMIZER_RANGE_H
 
-#include "drizzled/field.h"
-#include "drizzled/item/sum.h"
+#include <drizzled/field.h>
+#include <drizzled/item/sum.h>
+#include <drizzled/table_reference.h>
 
 #include <queue>
 
+#include <boost/dynamic_bitset.hpp>
+
 namespace drizzled
 {
 
@@ -312,9 +315,9 @@
 };
 
 QuickRangeSelect *get_quick_select_for_ref(Session *session, 
-                                             Table *table,
-                                             struct table_reference_st *ref,
-                                             ha_rows records);
+                                           Table *table,
+                                           table_reference_st *ref,
+                                           ha_rows records);
 
 /*
   Create a QuickRangeSelect from given key and SEL_ARG tree for that key.

=== modified file 'drizzled/optimizer/sum.cc'
--- drizzled/optimizer/sum.cc	2010-12-18 04:43:40 +0000
+++ drizzled/optimizer/sum.cc	2011-02-09 22:48:12 +0000
@@ -56,6 +56,7 @@
 #include "drizzled/item/sum.h"
 #include "drizzled/item/cmpfunc.h"
 #include "drizzled/optimizer/sum.h"
+#include "drizzled/plugin/storage_engine.h"
 
 namespace drizzled
 {

=== modified file 'drizzled/plugin/client.cc'
--- drizzled/plugin/client.cc	2011-01-17 16:48:48 +0000
+++ drizzled/plugin/client.cc	2011-02-11 21:34:53 +0000
@@ -18,8 +18,11 @@
  */
 
 #include "config.h"
+
 #include <cstdio>
-#include "drizzled/plugin/client.h"
+
+#include <drizzled/plugin/client.h>
+#include <drizzled/type/time.h>
 
 namespace drizzled
 {

=== modified file 'drizzled/plugin/client.h'
--- drizzled/plugin/client.h	2011-02-01 17:15:16 +0000
+++ drizzled/plugin/client.h	2011-02-11 21:34:53 +0000
@@ -20,8 +20,11 @@
 #ifndef DRIZZLED_PLUGIN_CLIENT_H
 #define DRIZZLED_PLUGIN_CLIENT_H
 
+#include <drizzled/catalog/instance.h>
+#include <drizzled/catalog/local.h>
+#include <drizzled/error_t.h>
+#include <drizzled/item.h>
 #include <drizzled/sql_list.h>
-#include <drizzled/item.h>
 
 #include "drizzled/visibility.h"
 
@@ -111,7 +114,7 @@
     return false;
   }
 
-  virtual  catalog::Instance::shared_ptr catalog()
+  virtual catalog::Instance::shared_ptr catalog()
   {
     return catalog::local();
   }

=== modified file 'drizzled/plugin/function.h'
--- drizzled/plugin/function.h	2011-01-26 19:15:55 +0000
+++ drizzled/plugin/function.h	2011-02-11 21:34:53 +0000
@@ -21,13 +21,16 @@
 #define DRIZZLED_PLUGIN_FUNCTION_H
 
 
-#include "drizzled/plugin/plugin.h"
-#include "drizzled/item/func.h"
+#include <drizzled/item/func.h>
+#include <drizzled/plugin.h>
+#include <drizzled/plugin/plugin.h>
 
 #include <string>
 #include <vector>
 #include <functional>
 
+#include <boost/unordered_map.hpp>
+
 #include "drizzled/visibility.h"
 
 namespace drizzled
@@ -40,6 +43,12 @@
   class Root;
 }
 
+namespace util
+{
+struct insensitive_hash;
+struct insensitive_equal_to;
+}
+
 namespace plugin
 {
 

=== modified file 'drizzled/plugin/listen.cc'
--- drizzled/plugin/listen.cc	2011-02-02 14:37:13 +0000
+++ drizzled/plugin/listen.cc	2011-02-09 22:48:12 +0000
@@ -18,8 +18,10 @@
  */
 
 #include "config.h"
+
+#include <drizzled/errmsg_print.h>
+#include <drizzled/error.h>
 #include <drizzled/gettext.h>
-#include <drizzled/error.h>
 #include <drizzled/plugin/listen.h>
 #include <drizzled/plugin/listen.h>
 #include <drizzled/plugin/null_client.h>

=== modified file 'drizzled/plugin/query_rewrite.h'
--- drizzled/plugin/query_rewrite.h	2011-01-26 19:15:55 +0000
+++ drizzled/plugin/query_rewrite.h	2011-02-12 08:10:17 +0000
@@ -26,7 +26,6 @@
 
 #include "drizzled/atomics.h"
 #include "drizzled/plugin/plugin.h"
-#include "drizzled/session.h"
 
 #include "drizzled/visibility.h"
 

=== modified file 'drizzled/plugin/storage_engine.cc'
--- drizzled/plugin/storage_engine.cc	2011-02-04 08:47:29 +0000
+++ drizzled/plugin/storage_engine.cc	2011-02-09 22:48:12 +0000
@@ -847,7 +847,7 @@
     - table->getShare()->path
     - table->alias
 */
-void StorageEngine::print_error(int error, myf errflag, Table &table)
+void StorageEngine::print_error(int error, myf errflag, const Table &table) const
 {
   drizzled::error_t textno= ER_GET_ERRNO;
   switch (error) {
@@ -1051,13 +1051,13 @@
   @return
     Returns true if this is a temporary error
 */
-bool StorageEngine::get_error_message(int , String* )
+bool StorageEngine::get_error_message(int , String* ) const
 {
   return false;
 }
 
 
-void StorageEngine::print_keydup_error(uint32_t key_nr, const char *msg, Table &table)
+void StorageEngine::print_keydup_error(uint32_t key_nr, const char *msg, const Table &table) const
 {
   /* Write the duplicated key in the error message */
   char key[MAX_KEY_LENGTH];

=== modified file 'drizzled/plugin/storage_engine.h'
--- drizzled/plugin/storage_engine.h	2011-01-26 19:15:55 +0000
+++ drizzled/plugin/storage_engine.h	2011-02-10 22:27:27 +0000
@@ -21,25 +21,24 @@
 #define DRIZZLED_PLUGIN_STORAGE_ENGINE_H
 
 
+#include <drizzled/cached_directory.h>
 #include <drizzled/definitions.h>
-#include <drizzled/plugin.h>
+#include <drizzled/error_t.h>
 #include <drizzled/handler_structs.h>
+#include <drizzled/identifier.h>
 #include <drizzled/message.h>
 #include <drizzled/message/cache.h>
-#include "drizzled/plugin/plugin.h"
-#include "drizzled/sql_string.h"
-#include "drizzled/identifier.h"
-#include "drizzled/cached_directory.h"
-#include "drizzled/plugin/monitored_in_transaction.h"
-
-#include <drizzled/error_t.h>
+#include <drizzled/plugin.h>
+#include <drizzled/plugin/monitored_in_transaction.h>
+#include <drizzled/plugin/plugin.h>
+#include <drizzled/sql_string.h>
 
 #include <bitset>
 #include <string>
 #include <vector>
 #include <set>
 
-#include "drizzled/visibility.h"
+#include <drizzled/visibility.h>
 
 namespace drizzled
 {
@@ -223,11 +222,11 @@
   }
 
   /* Old style cursor errors */
-  void print_keydup_error(uint32_t key_nr, const char *msg, Table &table);
-  virtual bool get_error_message(int error, String *buf);
+  void print_keydup_error(uint32_t key_nr, const char *msg, const Table &table) const;
+  virtual bool get_error_message(int error, String *buf) const;
 
 public:
-  virtual void print_error(int error, myf errflag, Table& table);
+  virtual void print_error(int error, myf errflag, const Table& table) const;
 
   bool is_user_selectable() const
   {

=== modified file 'drizzled/plugin/table_function.cc'
--- drizzled/plugin/table_function.cc	2011-01-11 07:12:09 +0000
+++ drizzled/plugin/table_function.cc	2011-02-11 21:34:53 +0000
@@ -19,12 +19,13 @@
 
 #include "config.h"
 
+#include <drizzled/current_session.h>
+#include <drizzled/gettext.h>
+#include <drizzled/global_charset_info.h>
 #include <drizzled/plugin/table_function.h>
+#include <drizzled/session.h>
+#include <drizzled/show.h>
 #include <drizzled/table_function_container.h>
-#include <drizzled/gettext.h>
-#include "drizzled/global_charset_info.h"
-#include "drizzled/session.h"
-#include "drizzled/current_session.h"
 
 #include <vector>
 

=== modified file 'drizzled/plugin/table_function.h'
--- drizzled/plugin/table_function.h	2011-01-26 19:15:55 +0000
+++ drizzled/plugin/table_function.h	2011-02-11 21:34:53 +0000
@@ -40,9 +40,6 @@
 namespace drizzled
 {
 
-extern int wild_case_compare(const CHARSET_INFO * const cs, 
-                             const char *str,const char *wildstr);
-
 namespace plugin
 {
 

=== modified file 'drizzled/pthread_globals.h'
--- drizzled/pthread_globals.h	2011-01-27 07:11:39 +0000
+++ drizzled/pthread_globals.h	2011-02-07 19:00:19 +0000
@@ -21,7 +21,6 @@
 #define DRIZZLED_PTHREAD_GLOBALS_H
 
 #include <pthread.h>
-#include <boost/thread/recursive_mutex.hpp>
 #include <boost/thread/mutex.hpp>
 #include <boost/thread/shared_mutex.hpp>
 #include <boost/thread/condition_variable.hpp>

=== modified file 'drizzled/query_id.h'
--- drizzled/query_id.h	2010-12-18 04:43:40 +0000
+++ drizzled/query_id.h	2011-02-10 00:22:35 +0000
@@ -20,7 +20,6 @@
 #ifndef DRIZZLED_QUERY_ID_H
 #define DRIZZLED_QUERY_ID_H
 
-#include <pthread.h>
 #include <drizzled/atomics.h>
 
 namespace drizzled

=== modified file 'drizzled/records.cc'
--- drizzled/records.cc	2011-01-06 06:56:27 +0000
+++ drizzled/records.cc	2011-02-09 22:48:12 +0000
@@ -20,14 +20,16 @@
   Functions for easy reading of records, possible through a cache
 */
 #include "config.h"
+
+#include "drizzled/drizzled.h"
 #include "drizzled/error.h"
+#include "drizzled/internal/iocache.h"
+#include "drizzled/internal/my_sys.h"
+#include "drizzled/optimizer/range.h"
+#include "drizzled/plugin/storage_engine.h"
+#include "drizzled/records.h"
+#include "drizzled/session.h"
 #include "drizzled/table.h"
-#include "drizzled/session.h"
-#include "drizzled/records.h"
-#include "drizzled/optimizer/range.h"
-#include "drizzled/internal/my_sys.h"
-#include "drizzled/internal/iocache.h"
-#include "drizzled/drizzled.h"
 
 namespace drizzled
 {

=== added file 'drizzled/refresh_version.cc'
--- drizzled/refresh_version.cc	1970-01-01 00:00:00 +0000
+++ drizzled/refresh_version.cc	2011-02-09 00:29:59 +0000
@@ -0,0 +1,35 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_REFRESH_VERSION_H
+#define DRIZZLED_REFRESH_VERSION_H
+
+#include "config.h"
+
+namespace drizzled
+{
+
+/** 
+  Refresh value. We use to test this to find out if a refresh even has happened recently.
+*/
+uint64_t refresh_version;  /* Increments on each reload */
+
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_REFRESH_VERSION_H */

=== added file 'drizzled/refresh_version.h'
--- drizzled/refresh_version.h	1970-01-01 00:00:00 +0000
+++ drizzled/refresh_version.h	2011-02-09 00:29:59 +0000
@@ -0,0 +1,34 @@
+
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2009 Sun Microsystems, Inc.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_REFRESH_VERSION_H
+#define DRIZZLED_REFRESH_VERSION_H
+
+namespace drizzled
+{
+
+/** 
+  Refresh value. We use to test this to find out if a refresh even has happened recently.
+*/
+extern uint64_t refresh_version;  /* Increments on each reload */
+
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_REFRESH_VERSION_H */

=== modified file 'drizzled/select_result.h'
--- drizzled/select_result.h	2011-01-16 20:38:08 +0000
+++ drizzled/select_result.h	2011-02-07 19:00:19 +0000
@@ -21,6 +21,8 @@
 #ifndef DRIZZLED_SELECT_RESULT_H
 #define DRIZZLED_SELECT_RESULT_H
 
+#include <drizzled/current_session.h>
+
 namespace drizzled
 {
 
@@ -30,6 +32,7 @@
 protected:
   Session *session;
   Select_Lex_Unit *unit;
+
 public:
   select_result()
   {

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2011-02-11 01:06:19 +0000
+++ drizzled/session.cc	2011-02-12 10:06:03 +0000
@@ -22,9 +22,10 @@
  */
 
 #include "config.h"
+
+#include <drizzled/copy_field.h>
 #include "drizzled/session.h"
 #include "drizzled/session/cache.h"
-#include <sys/stat.h>
 #include "drizzled/error.h"
 #include "drizzled/gettext.h"
 #include "drizzled/query_id.h"
@@ -51,6 +52,8 @@
 
 #include "drizzled/identifier.h"
 
+#include <drizzled/refresh_version.h>
+
 #include "drizzled/table/singular.h"
 
 #include "plugin/myisam/myisam.h"
@@ -62,9 +65,10 @@
 
 #include "drizzled/display.h"
 
-#include <fcntl.h>
 #include <algorithm>
 #include <climits>
+#include <fcntl.h>
+#include <sys/stat.h>
 
 #include <boost/filesystem.hpp>
 #include <boost/checked_delete.hpp>
@@ -388,12 +392,6 @@
 
   plugin::Logging::postEndDo(this);
   plugin::EventObserver::deregisterSessionEvents(*this); 
-
-  for (PropertyMap::iterator iter= life_properties.begin(); iter != life_properties.end(); iter++)
-  {
-    boost::checked_delete((*iter).second);
-  }
-  life_properties.clear();
 }
 
 void Session::setClient(plugin::Client *client_arg)
@@ -715,7 +713,7 @@
     plugin::QueryRewriter::rewriteQuery(*_schema, *new_query);
   }
   query.reset(new_query);
-  _state.reset(new State(in_packet, in_packet_length));
+  _state.reset(new session::State(in_packet, in_packet_length));
 
   return true;
 }
@@ -873,7 +871,7 @@
                                      bool allocate_lex_string)
 {
   if (allocate_lex_string)
-    if (!(lex_str= (LEX_STRING *)alloc(sizeof(LEX_STRING))))
+    if (!(lex_str= (LEX_STRING *)getMemRoot()->allocate(sizeof(LEX_STRING))))
       return 0;
   if (!(lex_str->str= mem_root->strmake_root(str, length)))
     return 0;
@@ -2009,74 +2007,6 @@
   }
 }
 
-bool Session::TableMessages::storeTableMessage(const identifier::Table &identifier, message::Table &table_message)
-{
-  table_message_cache.insert(make_pair(identifier.getPath(), table_message));
-
-  return true;
-}
-
-bool Session::TableMessages::removeTableMessage(const identifier::Table &identifier)
-{
-  TableMessageCache::iterator iter;
-
-  iter= table_message_cache.find(identifier.getPath());
-
-  if (iter == table_message_cache.end())
-    return false;
-
-  table_message_cache.erase(iter);
-
-  return true;
-}
-
-bool Session::TableMessages::getTableMessage(const identifier::Table &identifier, message::Table &table_message)
-{
-  TableMessageCache::iterator iter;
-
-  iter= table_message_cache.find(identifier.getPath());
-
-  if (iter == table_message_cache.end())
-    return false;
-
-  table_message.CopyFrom(((*iter).second));
-
-  return true;
-}
-
-bool Session::TableMessages::doesTableMessageExist(const identifier::Table &identifier)
-{
-  TableMessageCache::iterator iter;
-
-  iter= table_message_cache.find(identifier.getPath());
-
-  if (iter == table_message_cache.end())
-  {
-    return false;
-  }
-
-  return true;
-}
-
-bool Session::TableMessages::renameTableMessage(const identifier::Table &from, const identifier::Table &to)
-{
-  TableMessageCache::iterator iter;
-
-  table_message_cache[to.getPath()]= table_message_cache[from.getPath()];
-
-  iter= table_message_cache.find(to.getPath());
-
-  if (iter == table_message_cache.end())
-  {
-    return false;
-  }
-
-  (*iter).second.set_schema(to.getSchemaName());
-  (*iter).second.set_name(to.getTableName());
-
-  return true;
-}
-
 table::Singular *Session::getInstanceTable()
 {
   temporary_shares.push_back(new table::Singular()); // This will not go into the tableshare cache, so no key is used.

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2011-02-11 16:10:26 +0000
+++ drizzled/session.h	2011-02-12 10:06:03 +0000
@@ -17,47 +17,51 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-
-
 #ifndef DRIZZLED_SESSION_H
 #define DRIZZLED_SESSION_H
 
+#include "drizzled/cursor.h"
+#include "drizzled/diagnostics_area.h"
+#include "drizzled/file_exchange.h"
+#include "drizzled/identifier.h"
+#include "drizzled/internal_error_handler.h"
+#include "drizzled/my_hash.h"
+#include "drizzled/named_savepoint.h"
+#include "drizzled/open_tables_state.h"
 #include "drizzled/plugin.h"
-#include "drizzled/sql_locale.h"
+#include "drizzled/plugin/authorization.h"
+#include "drizzled/pthread_globals.h"
+#include "drizzled/query_id.h"
 #include "drizzled/resource_context.h"
-#include "drizzled/cursor.h"
-#include "drizzled/current_session.h"
+#include "drizzled/select_result_interceptor.h"
 #include "drizzled/sql_error.h"
-#include "drizzled/file_exchange.h"
-#include "drizzled/select_result_interceptor.h"
+#include "drizzled/sql_locale.h"
 #include "drizzled/statistics_variables.h"
-#include "drizzled/xid.h"
-#include "drizzled/query_id.h"
-#include "drizzled/named_savepoint.h"
 #include "drizzled/transaction_context.h"
 #include "drizzled/util/storable.h"
-#include "drizzled/my_hash.h"
-#include "drizzled/pthread_globals.h"
+#include "drizzled/xid.h"
+
+
 #include <netdb.h>
 #include <sys/time.h>
 #include <sys/resource.h>
 
 #include <algorithm>
 #include <bitset>
-#include <deque>
 #include <map>
 #include <string>
 
-#include "drizzled/identifier.h"
-#include "drizzled/open_tables_state.h"
-#include "drizzled/internal_error_handler.h"
-#include "drizzled/diagnostics_area.h"
-#include "drizzled/plugin/authorization.h"
-
 #include "drizzled/catalog/instance.h"
 #include "drizzled/catalog/local.h"
 
-#include <boost/unordered_map.hpp>
+#include <drizzled/session/property_map.h>
+#include <drizzled/session/state.h>
+#include <drizzled/session/table_messages.h>
+#include <drizzled/session/transactions.h>
+#include <drizzled/system_variables.h>
+#include <drizzled/copy_info.h>
+#include <drizzled/system_variables.h>
+#include <drizzled/ha_data.h>
 
 #include <boost/thread/thread.hpp>
 #include <boost/thread/mutex.hpp>
@@ -65,6 +69,9 @@
 #include <boost/thread/condition_variable.hpp>
 #include <boost/make_shared.hpp>
 
+#include <drizzled/lex_column.h>
+#include "drizzled/sql_lex.h"
+
 #include "drizzled/visibility.h"
 
 #define MIN_HANDSHAKE_SIZE      6
@@ -86,15 +93,9 @@
 class Resultset;
 }
 
-namespace internal
-{
-struct st_my_thread_var;
-}
+namespace internal { struct st_my_thread_var; }
 
-namespace table
-{
-class Placeholder;
-}
+namespace table { class Placeholder; }
 
 class Lex_input_stream;
 class user_var_entry;
@@ -111,188 +112,14 @@
 #define TC_HEURISTIC_RECOVER_ROLLBACK 2
 extern uint32_t tc_heuristic_recover;
 
-/**
-  @brief
-  Local storage for proto that are tmp table. This should be enlarged
-  to hande the entire table-share for a local table. Once Hash is done,
-  we should consider exchanging the map for it.
-*/
-typedef std::map <std::string, message::Table> ProtoCache;
-
-/**
-  The COPY_INFO structure is used by INSERT/REPLACE code.
-  The schema of the row counting by the INSERT/INSERT ... ON DUPLICATE KEY
-  UPDATE code:
-    If a row is inserted then the copied variable is incremented.
-    If a row is updated by the INSERT ... ON DUPLICATE KEY UPDATE and the
-      new data differs from the old one then the copied and the updated
-      variables are incremented.
-    The touched variable is incremented if a row was touched by the update part
-      of the INSERT ... ON DUPLICATE KEY UPDATE no matter whether the row
-      was actually changed or not.
-*/
-class CopyInfo 
-{
-public:
-  ha_rows records; /**< Number of processed records */
-  ha_rows deleted; /**< Number of deleted records */
-  ha_rows updated; /**< Number of updated records */
-  ha_rows copied;  /**< Number of copied records */
-  ha_rows error_count;
-  ha_rows touched; /* Number of touched records */
-  enum enum_duplicates handle_duplicates;
-  int escape_char, last_errno;
-  bool ignore;
-  /* for INSERT ... UPDATE */
-  List<Item> *update_fields;
-  List<Item> *update_values;
-  /* for VIEW ... WITH CHECK OPTION */
-
-  CopyInfo() :
-    records(0),
-    deleted(0),
-    updated(0),
-    copied(0),
-    error_count(0),
-    touched(0),
-    escape_char(0),
-    last_errno(0),
-    ignore(0),
-    update_fields(0),
-    update_values(0)
-  { }
-
-};
-
-} /* namespace drizzled */
-
-/** @TODO why is this in the middle of the file */
-#include <drizzled/lex_column.h>
-
-namespace drizzled
-{
-
 class select_result;
 class Time_zone;
 
 #define Session_SENTRY_MAGIC 0xfeedd1ff
 #define Session_SENTRY_GONE  0xdeadbeef
 
-struct drizzle_system_variables
-{
-  drizzle_system_variables()
-  {}
-  /*
-    How dynamically allocated system variables are handled:
-
-    The global_system_variables and max_system_variables are "authoritative"
-    They both should have the same 'version' and 'size'.
-    When attempting to access a dynamic variable, if the session version
-    is out of date, then the session version is updated and realloced if
-    neccessary and bytes copied from global to make up for missing data.
-  */
-  ulong dynamic_variables_version;
-  char * dynamic_variables_ptr;
-  uint32_t dynamic_variables_head;  /* largest valid variable offset */
-  uint32_t dynamic_variables_size;  /* how many bytes are in use */
-
-  uint64_t myisam_max_extra_sort_file_size;
-  uint64_t max_heap_table_size;
-  uint64_t tmp_table_size;
-  ha_rows select_limit;
-  ha_rows max_join_size;
-  uint64_t auto_increment_increment;
-  uint64_t auto_increment_offset;
-  uint64_t bulk_insert_buff_size;
-  uint64_t join_buff_size;
-  uint32_t max_allowed_packet;
-  uint64_t max_error_count;
-  uint64_t max_length_for_sort_data;
-  size_t max_sort_length;
-  uint64_t min_examined_row_limit;
-  bool optimizer_prune_level;
-  bool log_warnings;
-
-  uint32_t optimizer_search_depth;
-  uint32_t div_precincrement;
-  uint64_t preload_buff_size;
-  uint32_t read_buff_size;
-  uint32_t read_rnd_buff_size;
-  bool replicate_query;
-  size_t sortbuff_size;
-  uint32_t thread_handling;
-  uint32_t tx_isolation;
-  uint32_t completion_type;
-  /* Determines which non-standard SQL behaviour should be enabled */
-  uint32_t sql_mode;
-  uint64_t max_seeks_for_key;
-  size_t range_alloc_block_size;
-  uint32_t query_alloc_block_size;
-  uint32_t query_prealloc_size;
-  uint64_t group_concat_max_len;
-  uint64_t pseudo_thread_id;
-
-  plugin::StorageEngine *storage_engine;
-
-  /* Only charset part of these variables is sensible */
-  const CHARSET_INFO  *character_set_filesystem;
-
-  /* Both charset and collation parts of these variables are important */
-  const CHARSET_INFO	*collation_server;
-
-  inline const CHARSET_INFO  *getCollation(void) 
-  {
-    return collation_server;
-  }
-
-  /* Locale Support */
-  MY_LOCALE *lc_time_names;
-
-  Time_zone *time_zone;
-};
-
 extern DRIZZLED_API struct drizzle_system_variables global_system_variables;
 
-} /* namespace drizzled */
-
-#include "drizzled/sql_lex.h"
-
-namespace drizzled
-{
-
-/**
-  Storage engine specific thread local data.
-*/
-struct Ha_data
-{
-  /**
-    Storage engine specific thread local data.
-    Lifetime: one user connection.
-  */
-  void *ha_ptr;
-  /**
-   * Resource contexts for both the "statement" and "normal"
-   * transactions.
-   *
-   * Resource context at index 0:
-   *
-   * Life time: one statement within a transaction. If @@autocommit is
-   * on, also represents the entire transaction.
-   *
-   * Resource context at index 1:
-   *
-   * Life time: one transaction within a connection. 
-   *
-   * @note
-   *
-   * If the storage engine does not participate in a transaction, 
-   * there will not be a resource context.
-   */
-  drizzled::ResourceContext resource_context[2];
-
-  Ha_data() :ha_ptr(NULL) {}
-};
-
 /**
  * Represents a client connection to the database server.
  *
@@ -313,13 +140,10 @@
  * session object.
  */
 
-class DRIZZLED_API Session :
-  public Open_tables_state
+class DRIZZLED_API Session : public Open_tables_state
 {
 public:
   // Plugin storage in Session.
-  typedef boost::unordered_map<std::string, util::Storable *, util::insensitive_hash, util::insensitive_equal_to> PropertyMap;
-  typedef Session* Ptr;
   typedef boost::shared_ptr<Session> shared_ptr;
   typedef Session& reference;
   typedef const Session& const_reference;
@@ -344,10 +168,6 @@
                         and update_row.
   */
   enum enum_mark_columns mark_used_columns;
-  inline void* alloc(size_t size)
-  {
-    return mem_root->alloc_root(size);
-  }
   inline void* calloc(size_t size)
   {
     void *ptr;
@@ -355,18 +175,11 @@
       memset(ptr, 0, size);
     return ptr;
   }
-  inline char *strdup(const char *str)
-  {
-    return mem_root->strdup_root(str);
-  }
   inline char *strmake(const char *str, size_t size)
   {
     return mem_root->strmake_root(str,size);
   }
-  inline void *memdup(const void *str, size_t size)
-  {
-    return mem_root->memdup_root(str, size);
-  }
+
   inline void *memdup_w_gap(const void *str, size_t size, uint32_t gap)
   {
     void *ptr;
@@ -376,6 +189,7 @@
   }
   /** Frees all items attached to this Statement */
   void free_items();
+
   /**
    * List of items created in the parser for this query. Every item puts
    * itself to the list on creation (see Item::Item() for details))
@@ -422,6 +236,7 @@
 
   /** query associated with this statement */
   typedef boost::shared_ptr<const std::string> QueryString;
+
 private:
   boost::shared_ptr<std::string> query;
 
@@ -460,54 +275,12 @@
     return to_return;
   }
 
-  class State {
-    std::vector <char> _query;
-
-  public:
-    typedef boost::shared_ptr<State> const_shared_ptr;
-
-    State(const char *in_packet, size_t in_packet_length)
-    {
-      if (in_packet_length)
-      {
-        size_t minimum= std::min(in_packet_length, static_cast<size_t>(PROCESS_LIST_WIDTH));
-        _query.resize(minimum + 1);
-        memcpy(&_query[0], in_packet, minimum);
-      }
-      else
-      {
-        _query.resize(0);
-      }
-    }
-
-    const char *query() const
-    {
-      if (_query.size())
-        return &_query[0];
-
-      return "";
-    }
-
-    const char *query(size_t &size) const
-    {
-      if (_query.size())
-      {
-        size= _query.size() -1;
-        return &_query[0];
-      }
-
-      size= 0;
-      return "";
-    }
-  protected:
-    friend class Session;
-    typedef boost::shared_ptr<State> shared_ptr;
-  };
 private:
-  State::shared_ptr  _state; 
+  session::State::shared_ptr  _state; 
+
 public:
 
-  State::const_shared_ptr state()
+  session::State::const_shared_ptr state()
   {
     return _state;
   }
@@ -526,6 +299,7 @@
   */
 private:
   util::string::shared_ptr _schema;
+
 public:
 
   util::string::const_shared_ptr schema() const
@@ -568,12 +342,12 @@
   void *scheduler_arg; /**< Pointer to the optional scheduler argument */
 
   typedef boost::unordered_map< std::string, user_var_entry *, util::insensitive_hash, util::insensitive_equal_to> UserVars;
+
 private:
   typedef std::pair< UserVars::iterator, UserVars::iterator > UserVarsRange;
   UserVars user_vars; /**< Hash of user variables defined during the session's lifetime */
 
 public:
-
   const UserVars &getUserVariables() const
   {
     return user_vars;
@@ -606,6 +380,7 @@
   {
     assert(this->dbug_sentry == Session_SENTRY_MAGIC);
   }
+
 public:
   identifier::User::const_shared_ptr user() const
   {
@@ -667,8 +442,8 @@
   boost::this_thread::disable_interruption *interrupt;
 
   internal::st_my_thread_var *mysys_var;
+
 public:
-
   boost_thread_shared_ptr &getThread()
   {
     return _thread;
@@ -749,51 +524,7 @@
   ResourceContext *getResourceContext(const plugin::MonitoredInTransaction *monitored,
                                       size_t index= 0);
 
-  /**
-   * Structure used to manage "statement transactions" and
-   * "normal transactions". In autocommit mode, the normal transaction is
-   * equivalent to the statement transaction.
-   *
-   * Storage engines will be registered here when they participate in
-   * a transaction. No engine is registered more than once.
-   */
-  struct st_transactions {
-    std::deque<NamedSavepoint> savepoints;
-
-    /**
-     * The normal transaction (since BEGIN WORK).
-     *
-     * Contains a list of all engines that have participated in any of the
-     * statement transactions started within the context of the normal
-     * transaction.
-     *
-     * @note In autocommit mode, this is empty.
-     */
-    TransactionContext all;
-
-    /**
-     * The statment transaction.
-     *
-     * Contains a list of all engines participating in the given statement.
-     *
-     * @note In autocommit mode, this will be used to commit/rollback the
-     * normal transaction.
-     */
-    TransactionContext stmt;
-
-    XID_STATE xid_state;
-
-    void cleanup()
-    {
-      savepoints.clear();
-    }
-    st_transactions() :
-      savepoints(),
-      all(),
-      stmt(),
-      xid_state()
-    { }
-  } transaction;
+  session::Transactions transaction;
 
   Field *dup_field;
   sigset_t signals;
@@ -801,6 +532,7 @@
   // As of right now we do not allow a concurrent execute to launch itself
 private:
   bool concurrent_execute_allowed;
+
 public:
 
   void setConcurrentExecute(bool arg)
@@ -1854,25 +1586,11 @@
   table::Placeholder *table_cache_insert_placeholder(const identifier::Table &identifier);
   bool lock_table_name_if_not_cached(const identifier::Table &identifier, Table **table);
 
-  typedef boost::unordered_map<std::string, message::Table, util::insensitive_hash, util::insensitive_equal_to> TableMessageCache;
-
-  class TableMessages
-  {
-    TableMessageCache table_message_cache;
-
-  public:
-    bool storeTableMessage(const identifier::Table &identifier, message::Table &table_message);
-    bool removeTableMessage(const identifier::Table &identifier);
-    bool getTableMessage(const identifier::Table &identifier, message::Table &table_message);
-    bool doesTableMessageExist(const identifier::Table &identifier);
-    bool renameTableMessage(const identifier::Table &from, const identifier::Table &to);
-  };
-
 private:
-  TableMessages _table_message_cache;
+  session::TableMessages _table_message_cache;
 
 public:
-  TableMessages &getMessageCache()
+  session::TableMessages &getMessageCache()
   {
     return _table_message_cache;
   }
@@ -1887,13 +1605,13 @@
 
   drizzled::util::Storable *getProperty(const std::string &arg)
   {
-    return life_properties[arg];
+    return life_properties.getProperty(arg);
   }
 
   template<class T>
   bool setProperty(const std::string &arg, T *value)
   {
-    life_properties[arg]= value;
+    life_properties.setProperty(arg, value);
 
     return true;
   }
@@ -1928,6 +1646,7 @@
 
     return true;
   }
+
 public:
 
   void setUsage(bool arg)
@@ -1955,7 +1674,7 @@
 
   // This lives throughout the life of Session
   bool use_usage;
-  PropertyMap life_properties;
+  session::PropertyMap life_properties;
   std::vector<table::Singular *> temporary_shares;
   struct rusage usage;
 };
@@ -2043,6 +1762,7 @@
 namespace display  {
 const std::string &type(drizzled::Session::global_read_lock_t type);
 size_t max_string_length(drizzled::Session::global_read_lock_t type);
+
 } /* namespace display */
 
 } /* namespace drizzled */

=== modified file 'drizzled/session/cache.cc'
--- drizzled/session/cache.cc	2011-01-25 23:29:53 +0000
+++ drizzled/session/cache.cc	2011-02-09 00:29:59 +0000
@@ -21,10 +21,10 @@
 
 #include <vector>
 
-#include "drizzled/session/cache.h"
-#include "drizzled/session.h"
-#include "drizzled/current_session.h"
-#include "drizzled/plugin/authorization.h"
+#include <drizzled/session.h>
+#include <drizzled/session/cache.h>
+#include <drizzled/current_session.h>
+#include <drizzled/plugin/authorization.h>
 
 #include <boost/foreach.hpp>
 

=== modified file 'drizzled/session/cache.h'
--- drizzled/session/cache.h	2011-01-26 19:15:55 +0000
+++ drizzled/session/cache.h	2011-02-09 00:29:59 +0000
@@ -22,14 +22,11 @@
 
 #include <list>
 
-#include "drizzled/session.h"
-#include "drizzled/visibility.h"
+#include <drizzled/visibility.h>
 
 namespace drizzled
 {
 
-class Session;
-
 namespace session
 {
 

=== added file 'drizzled/session/property_map.h'
--- drizzled/session/property_map.h	1970-01-01 00:00:00 +0000
+++ drizzled/session/property_map.h	2011-02-07 20:21:09 +0000
@@ -0,0 +1,92 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_SESSION_PROPERTY_MAP_H
+#define DRIZZLED_SESSION_PROPERTY_MAP_H
+
+#include <drizzled/util/string.h>
+#include <boost/unordered_map.hpp>
+
+namespace drizzled
+{
+
+class Session;
+
+namespace session
+{
+
+class PropertyMap {
+private:
+  typedef boost::unordered_map<std::string, util::Storable *, util::insensitive_hash, util::insensitive_equal_to> Map;
+
+public:
+  typedef Map::iterator iterator;
+  typedef Map::const_iterator const_iterator;
+
+  drizzled::util::Storable *getProperty(const std::string &arg)
+  {
+    return _properties[arg];
+  }
+
+  template<class T>
+  bool setProperty(const std::string &arg, T *value)
+  {
+    _properties[arg]= value;
+
+    return true;
+  }
+
+  iterator begin()
+  {
+    return _properties.begin();
+  }
+
+  iterator end()
+  {
+    return _properties.end();
+  }
+
+  const_iterator begin() const
+  {
+    return _properties.begin();
+  }
+
+  const_iterator end() const
+  {
+    return _properties.end();
+  }
+
+  ~PropertyMap()
+  {
+    for (iterator iter= _properties.begin(); iter != _properties.end(); iter++)
+    {
+      boost::checked_delete((*iter).second);
+    }
+    _properties.clear();
+  }
+
+private:
+  Map _properties;
+};
+
+} /* namespace session */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_SESSION_PROPERTY_MAP_H */

=== added file 'drizzled/session/state.cc'
--- drizzled/session/state.cc	1970-01-01 00:00:00 +0000
+++ drizzled/session/state.cc	2011-02-07 17:58:52 +0000
@@ -0,0 +1,69 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include "drizzled/session/state.h"
+#include "drizzled/definitions.h"
+
+#include <string>
+
+namespace drizzled
+{
+
+namespace session
+{
+
+State::State(const char *in_packet, size_t in_packet_length)
+{
+  if (in_packet_length)
+  {
+    size_t minimum= std::min(in_packet_length, static_cast<size_t>(PROCESS_LIST_WIDTH));
+    _query.resize(minimum + 1);
+    memcpy(&_query[0], in_packet, minimum);
+  }
+  else
+  {
+    _query.resize(0);
+  }
+}
+
+const char *State::query() const
+{
+  if (_query.size())
+    return &_query[0];
+
+  return "";
+}
+
+const char *State::query(size_t &size) const
+{
+  if (_query.size())
+  {
+    size= _query.size() -1;
+    return &_query[0];
+  }
+
+  size= 0;
+  return "";
+}
+
+} /* namespace session */
+} /* namespace drizzled */

=== added file 'drizzled/session/state.h'
--- drizzled/session/state.h	1970-01-01 00:00:00 +0000
+++ drizzled/session/state.h	2011-02-07 17:58:52 +0000
@@ -0,0 +1,55 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_SESSION_STATE_H
+#define DRIZZLED_SESSION_STATE_H
+
+#include <drizzled/util/string.h>
+#include <boost/unordered_map.hpp>
+
+namespace drizzled
+{
+
+class Session;
+
+namespace session
+{
+
+class State {
+  std::vector <char> _query;
+
+public:
+  typedef boost::shared_ptr<State> shared_ptr;
+  typedef boost::shared_ptr<State> const_shared_ptr;
+
+  State(const char *in_packet, size_t in_packet_length);
+
+  const char *query() const;
+
+  const char *query(size_t &size) const;
+
+protected:
+  friend class Session;
+};
+
+} /* namespace session */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_SESSION_STATE_H */

=== added file 'drizzled/session/table_messages.cc'
--- drizzled/session/table_messages.cc	1970-01-01 00:00:00 +0000
+++ drizzled/session/table_messages.cc	2011-02-07 17:58:52 +0000
@@ -0,0 +1,105 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include "drizzled/util/string.h"
+#include "drizzled/session/table_messages.h"
+#include "drizzled/identifier.h"
+#include "drizzled/message/table.h"
+
+#include <string>
+
+namespace drizzled
+{
+
+namespace session
+{
+
+bool TableMessages::storeTableMessage(const identifier::Table &identifier, message::Table &table_message)
+{
+  table_message_cache.insert(make_pair(identifier.getPath(), table_message));
+
+  return true;
+}
+
+bool TableMessages::removeTableMessage(const identifier::Table &identifier)
+{
+  Cache::iterator iter;
+
+  iter= table_message_cache.find(identifier.getPath());
+
+  if (iter == table_message_cache.end())
+    return false;
+
+  table_message_cache.erase(iter);
+
+  return true;
+}
+
+bool TableMessages::getTableMessage(const identifier::Table &identifier, message::Table &table_message)
+{
+  Cache::iterator iter;
+
+  iter= table_message_cache.find(identifier.getPath());
+
+  if (iter == table_message_cache.end())
+    return false;
+
+  table_message.CopyFrom(((*iter).second));
+
+  return true;
+}
+
+bool TableMessages::doesTableMessageExist(const identifier::Table &identifier)
+{
+  Cache::iterator iter;
+
+  iter= table_message_cache.find(identifier.getPath());
+
+  if (iter == table_message_cache.end())
+  {
+    return false;
+  }
+
+  return true;
+}
+
+bool TableMessages::renameTableMessage(const identifier::Table &from, const identifier::Table &to)
+{
+  Cache::iterator iter;
+
+  table_message_cache[to.getPath()]= table_message_cache[from.getPath()];
+
+  iter= table_message_cache.find(to.getPath());
+
+  if (iter == table_message_cache.end())
+  {
+    return false;
+  }
+
+  (*iter).second.set_schema(to.getSchemaName());
+  (*iter).second.set_name(to.getTableName());
+
+  return true;
+}
+
+} /* namespace session */
+} /* namespace drizzled */

=== added file 'drizzled/session/table_messages.h'
--- drizzled/session/table_messages.h	1970-01-01 00:00:00 +0000
+++ drizzled/session/table_messages.h	2011-02-08 22:56:58 +0000
@@ -0,0 +1,57 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_SESSION_TABLE_MESSAGES_H
+#define DRIZZLED_SESSION_TABLE_MESSAGES_H
+
+#include <drizzled/util/string.h>
+#include <drizzled/message/table.h>
+
+#include <boost/unordered_map.hpp>
+
+namespace drizzled
+{
+
+namespace identifier { class Table; }
+namespace message { class Table; }
+namespace util { struct insensitive_hash; }
+namespace util { struct insensitive_equal_to; }
+
+namespace session
+{
+
+class TableMessages
+{
+  typedef boost::unordered_map<std::string, message::Table, util::insensitive_hash, util::insensitive_equal_to> Cache;
+
+  Cache table_message_cache;
+
+public:
+  bool storeTableMessage(const identifier::Table &identifier, message::Table &table_message);
+  bool removeTableMessage(const identifier::Table &identifier);
+  bool getTableMessage(const identifier::Table &identifier, message::Table &table_message);
+  bool doesTableMessageExist(const identifier::Table &identifier);
+  bool renameTableMessage(const identifier::Table &from, const identifier::Table &to);
+};
+
+} /* namespace session */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_SESSION_TABLE_MESSAGES_H */

=== added file 'drizzled/session/transactions.h'
--- drizzled/session/transactions.h	1970-01-01 00:00:00 +0000
+++ drizzled/session/transactions.h	2011-02-07 21:47:36 +0000
@@ -0,0 +1,85 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_SESSION_TRANSACTIONS_H
+#define DRIZZLED_SESSION_TRANSACTIONS_H
+
+#include <deque>
+
+namespace drizzled
+{
+
+class Session;
+
+namespace session
+{
+
+/**
+ * Structure used to manage "statement transactions" and
+ * "normal transactions". In autocommit mode, the normal transaction is
+ * equivalent to the statement transaction.
+ *
+ * Storage engines will be registered here when they participate in
+ * a transaction. No engine is registered more than once.
+ */
+class Transactions {
+public:
+  Transactions() :
+    savepoints(),
+    all(),
+    stmt(),
+    xid_state()
+  { }
+
+  std::deque<NamedSavepoint> savepoints;
+
+  /**
+   * The normal transaction (since BEGIN WORK).
+   *
+   * Contains a list of all engines that have participated in any of the
+   * statement transactions started within the context of the normal
+   * transaction.
+   *
+   * @note In autocommit mode, this is empty.
+   */
+  TransactionContext all;
+
+  /**
+   * The statment transaction.
+   *
+   * Contains a list of all engines participating in the given statement.
+   *
+   * @note In autocommit mode, this will be used to commit/rollback the
+   * normal transaction.
+   */
+  TransactionContext stmt;
+
+  XID_STATE xid_state;
+
+  void cleanup()
+  {
+    savepoints.clear();
+  }
+};
+
+} /* namespace session */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_SESSION_TRANSACTIONS_H */

=== modified file 'drizzled/show.cc'
--- drizzled/show.cc	2011-02-05 20:36:14 +0000
+++ drizzled/show.cc	2011-02-10 20:26:46 +0000
@@ -21,35 +21,14 @@
 
 /* Function with list databases, tables or fields */
 #include "config.h"
-#include <drizzled/sql_select.h>
-#include <drizzled/show.h>
-#include <drizzled/gettext.h>
-#include <drizzled/util/convert.h>
-#include <drizzled/error.h>
-#include <drizzled/tztime.h>
-#include <drizzled/data_home.h>
-#include <drizzled/item/blob.h>
-#include <drizzled/item/cmpfunc.h>
-#include <drizzled/item/return_int.h>
-#include <drizzled/item/empty_string.h>
-#include <drizzled/item/return_date_time.h>
-#include <drizzled/sql_base.h>
-#include <drizzled/db.h>
-#include <drizzled/field/epoch.h>
-#include <drizzled/field/decimal.h>
-#include <drizzled/lock.h>
-#include <drizzled/item/return_date_time.h>
-#include <drizzled/item/empty_string.h>
-#include "drizzled/session/cache.h"
-#include <drizzled/message/schema.pb.h>
-#include <drizzled/plugin/client.h>
-#include <drizzled/cached_directory.h>
-#include "drizzled/sql_table.h"
-#include "drizzled/global_charset_info.h"
-#include "drizzled/pthread_globals.h"
-#include "drizzled/internal/m_string.h"
+
+#include "drizzled/data_home.h"
+#include "drizzled/error.h"
 #include "drizzled/internal/my_sys.h"
-#include "drizzled/message/statement_transform.h"
+#include "drizzled/plugin/storage_engine.h"
+#include "drizzled/session.h"
+#include "drizzled/show.h"
+#include "drizzled/sql_select.h"
 
 #include "drizzled/statement/show.h"
 #include "drizzled/statement/show_errors.h"
@@ -75,7 +54,7 @@
   return str ? str : "<nil>";
 }
 
-int wild_case_compare(const CHARSET_INFO * const cs, const char *str, const char *wildstr)
+int wild_case_compare(const charset_info_st * const cs, const char *str, const char *wildstr)
 {
   register int flag;
 

=== modified file 'drizzled/show.h'
--- drizzled/show.h	2011-02-04 23:02:48 +0000
+++ drizzled/show.h	2011-02-10 20:26:46 +0000
@@ -27,12 +27,8 @@
 #ifndef DRIZZLED_SHOW_H
 #define DRIZZLED_SHOW_H
 
-#include <vector>
-
-#include "drizzled/sql_list.h"
+#include "drizzled/enum.h"
 #include "drizzled/lex_string.h"
-#include "drizzled/sql_parse.h"
-#include "drizzled/plugin.h"
 
 #include "drizzled/visibility.h"
 
@@ -40,17 +36,11 @@
 {
 
 /* Forward declarations */
-class String;
-class Join;
 class Session;
-struct st_ha_create_information;
-typedef st_ha_create_information HA_CREATE_INFO;
-class TableList;
-
-class Table;
-typedef class Item COND;
-
-int wild_case_compare(const CHARSET_INFO * const cs, 
+class Table_ident;
+struct charset_info_st;
+
+int wild_case_compare(const charset_info_st * const cs, 
                       const char *str,const char *wildstr);
 
 DRIZZLED_API int get_quote_char_for_identifier();

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2011-02-04 22:22:31 +0000
+++ drizzled/sql_base.cc	2011-02-09 22:48:12 +0000
@@ -56,6 +56,9 @@
 #include "drizzled/table/temporary.h"
 #include "drizzled/table/placeholder.h"
 #include "drizzled/table/unused.h"
+#include "drizzled/plugin/storage_engine.h"
+
+#include <drizzled/refresh_version.h>
 
 using namespace std;
 
@@ -1758,7 +1761,7 @@
   Table **start,**ptr;
   uint32_t lock_flag= DRIZZLE_LOCK_NOTIFY_IF_NEED_REOPEN;
 
-  if (!(ptr=start=(Table**) session->alloc(sizeof(Table*)*count)))
+  if (!(ptr=start=(Table**) session->getMemRoot()->allocate(sizeof(Table*)*count)))
     return -1;
 
   for (table= tables; table; table= table->next_global)

=== modified file 'drizzled/sql_lex.cc'
--- drizzled/sql_lex.cc	2011-02-07 17:01:15 +0000
+++ drizzled/sql_lex.cc	2011-02-10 07:07:28 +0000
@@ -50,7 +50,7 @@
 {
   Order *order;
 
-  if (!(order = (Order *) session->alloc(sizeof(Order))))
+  if (!(order = (Order *) session->getMemRoot()->allocate(sizeof(Order))))
     return true;
 
   order->item_ptr= item;
@@ -95,7 +95,7 @@
   ignore_space(1),
   in_comment(NO_COMMENT)
 {
-  m_cpp_buf= (char*) session->alloc(length + 1);
+  m_cpp_buf= (char*) session->getMemRoot()->allocate(length + 1);
   m_cpp_ptr= m_cpp_buf;
 }
 
@@ -122,7 +122,7 @@
     (m_buf_length / default_charset_info->mbminlen) *
     my_charset_utf8_bin.mbmaxlen;
 
-  m_body_utf8= (char *) session->alloc(body_utf8_length + 1);
+  m_body_utf8= (char *) session->getMemRoot()->allocate(body_utf8_length + 1);
   m_body_utf8_ptr= m_body_utf8;
   *m_body_utf8_ptr= 0;
 
@@ -358,7 +358,7 @@
   char *to;
   lip->yyUnget();                       // ptr points now after last token char
   tmp.length= lip->yytoklen=length;
-  tmp.str=(char*) lip->m_session->alloc(tmp.length+1);
+  tmp.str=(char*) lip->m_session->getMemRoot()->allocate(tmp.length+1);
   from= lip->get_tok_start() + skip;
   to= tmp.str;
   end= to+length;
@@ -434,7 +434,7 @@
       end-= post_skip;
       assert(end >= str);
 
-      if (!(start= (char*) lip->m_session->alloc((uint32_t) (end-str)+1)))
+      if (!(start= (char*) lip->m_session->getMemRoot()->allocate((uint32_t) (end-str)+1)))
         return (char*) "";		// memory::SqlAlloc has set error flag
 
       lip->m_cpp_text_start= lip->get_cpp_tok_start() + pre_skip;
@@ -1713,7 +1713,7 @@
     return false;
 
   return (ref_pointer_array=
-          (Item **)session->alloc(sizeof(Item*) * (n_child_sum_items +
+          (Item **)session->getMemRoot()->allocate(sizeof(Item*) * (n_child_sum_items +
                                                  item_list.elements +
                                                  select_n_having_items +
                                                  select_n_where_fields +

=== modified file 'drizzled/sql_load.cc'
--- drizzled/sql_load.cc	2011-01-26 02:13:21 +0000
+++ drizzled/sql_load.cc	2011-02-09 22:48:12 +0000
@@ -17,6 +17,7 @@
 /* Copy data from a textfile to table */
 
 #include "config.h"
+
 #include <drizzled/sql_load.h>
 #include <drizzled/error.h>
 #include <drizzled/data_home.h>
@@ -26,6 +27,7 @@
 #include "drizzled/internal/my_sys.h"
 #include "drizzled/internal/iocache.h"
 #include <drizzled/db.h>
+#include "drizzled/plugin/storage_engine.h"
 
 #include <sys/stat.h>
 #include <fcntl.h>

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2011-02-07 09:03:00 +0000
+++ drizzled/sql_parse.cc	2011-02-12 10:06:03 +0000
@@ -34,6 +34,7 @@
 #include <drizzled/item/cmpfunc.h>
 #include <drizzled/item/null.h>
 #include <drizzled/session.h>
+#include <drizzled/session/cache.h>
 #include <drizzled/sql_load.h>
 #include <drizzled/lock.h>
 #include <drizzled/select_send.h>
@@ -41,7 +42,6 @@
 #include <drizzled/statement.h>
 #include <drizzled/statement/alter_table.h>
 #include "drizzled/probes.h"
-#include "drizzled/session/cache.h"
 #include "drizzled/global_charset_info.h"
 
 #include "drizzled/plugin/logging.h"
@@ -971,7 +971,7 @@
                  ER(ER_DERIVED_MUST_HAVE_ALIAS), MYF(0));
       return NULL;
     }
-    if (!(alias_str= (char*) session->memdup(alias_str,table->table.length+1)))
+    if (!(alias_str= (char*) session->getMemRoot()->duplicate(alias_str,table->table.length+1)))
       return NULL;
   }
   if (!(ptr = (TableList *) session->calloc(sizeof(TableList))))

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2011-02-06 15:18:20 +0000
+++ drizzled/sql_select.cc	2011-02-10 07:07:28 +0000
@@ -52,6 +52,7 @@
 #include "drizzled/records.h"
 #include "drizzled/internal/iocache.h"
 #include "drizzled/drizzled.h"
+#include "drizzled/plugin/storage_engine.h"
 
 #include "drizzled/sql_union.h"
 #include "drizzled/optimizer/key_field.h"
@@ -572,7 +573,7 @@
   sz= sizeof(optimizer::KeyField) *
       (((session->lex->current_select->cond_count+1)*2 +
 	session->lex->current_select->between_count)*m+1);
-  if (! (key_fields= (optimizer::KeyField*) session->alloc(sz)))
+  if (! (key_fields= (optimizer::KeyField*) session->getMemRoot()->allocate(sz)))
     return true;
   and_level= 0;
   field= end= key_fields;
@@ -1004,10 +1005,10 @@
   j->ref.key_length=length;
   j->ref.key=(int) key;
   if (!(j->ref.key_buff= (unsigned char*) session->calloc(ALIGN_SIZE(length)*2)) ||
-      !(j->ref.key_copy= (StoredKey**) session->alloc((sizeof(StoredKey*) *
+      !(j->ref.key_copy= (StoredKey**) session->getMemRoot()->allocate((sizeof(StoredKey*) *
                (keyparts+1)))) ||
-      !(j->ref.items=    (Item**) session->alloc(sizeof(Item*)*keyparts)) ||
-      !(j->ref.cond_guards= (bool**) session->alloc(sizeof(uint*)*keyparts)))
+      !(j->ref.items=    (Item**) session->getMemRoot()->allocate(sizeof(Item*)*keyparts)) ||
+      !(j->ref.cond_guards= (bool**) session->getMemRoot()->allocate(sizeof(uint*)*keyparts)))
   {
     return(true);
   }
@@ -5636,7 +5637,7 @@
   {
     if (order->in_field_list)
     {
-      Order *ord=(Order*) session->memdup((char*) order,sizeof(Order));
+      Order *ord=(Order*) session->getMemRoot()->duplicate((char*) order,sizeof(Order));
       if (!ord)
         return 0;
       *prev=ord;
@@ -6291,7 +6292,7 @@
 {
   /* List is reversed => we should reverse it before using */
   List_iterator_fast<TableList> ti(*tables);
-  TableList **table= (TableList **)session->alloc(sizeof(TableList*) *
+  TableList **table= (TableList **)session->getMemRoot()->allocate(sizeof(TableList*) *
                                                 tables->elements);
   if (table == 0)
     return;  // out of memory

=== modified file 'drizzled/sql_select.h'
--- drizzled/sql_select.h	2011-02-06 15:18:20 +0000
+++ drizzled/sql_select.h	2011-02-12 06:17:39 +0000
@@ -21,7 +21,6 @@
 #define DRIZZLED_SQL_SELECT_H
 
 #include "drizzled/cached_item.h"
-#include "drizzled/session.h"
 #include "drizzled/field/varstring.h"
 #include "drizzled/item/null.h"
 #include <drizzled/enum_nested_loop_state.h>
@@ -31,13 +30,17 @@
 #include "drizzled/join_cache.h"
 #include "drizzled/join_table.h"
 #include "drizzled/records.h"
+#include "drizzled/stored_key.h"
 
 #include <vector>
 
 namespace drizzled
 {
 
+class Item_func;
+class Select_Lex_Unit;
 class select_result;
+class st_dynamic_array;
 
 /**
  * @file API and Classes to use when handling where clause
@@ -273,15 +276,6 @@
                         optimizer::KeyUse *org_keyuse, 
                         table_map used_tables);
 
-} /* namespace drizzled */
-
-/** @TODO why is this in the middle of the file??? */
-
-#include "drizzled/stored_key.h"
-
-namespace drizzled
-{
-
 bool cp_buffer_from_ref(Session *session, table_reference_st *ref);
 int safe_index_read(JoinTable *tab);
 COND *remove_eq_conds(Session *session, COND *cond, Item::cond_result *cond_value);

=== modified file 'drizzled/sql_string.h'
--- drizzled/sql_string.h	2011-01-28 18:48:01 +0000
+++ drizzled/sql_string.h	2011-02-10 22:27:27 +0000
@@ -23,6 +23,7 @@
 /* This file is originally from the mysql distribution. Coded by monty */
 
 #include <drizzled/common.h>
+
 #include <cassert>
 #include <cstdlib>
 #include <cstring>

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2011-02-08 04:42:44 +0000
+++ drizzled/sql_table.cc	2011-02-12 10:06:03 +0000
@@ -47,6 +47,7 @@
 #include "drizzled/statement/alter_table.h"
 #include "drizzled/sql_table.h"
 #include "drizzled/pthread_globals.h"
+#include "drizzled/plugin/storage_engine.h"
 
 #include <algorithm>
 #include <sstream>

=== modified file 'drizzled/sql_update.cc'
--- drizzled/sql_update.cc	2011-02-07 01:54:33 +0000
+++ drizzled/sql_update.cc	2011-02-10 07:07:28 +0000
@@ -16,9 +16,10 @@
 
 /*
   Single table and multi table updates of tables.
-  Multi-table updates were introduced by Sinisa & Monty
 */
+
 #include "config.h"
+
 #include "drizzled/sql_select.h"
 #include "drizzled/error.h"
 #include "drizzled/probes.h"
@@ -31,6 +32,7 @@
 #include "drizzled/internal/iocache.h"
 #include "drizzled/transaction_services.h"
 #include "drizzled/filesort.h"
+#include "drizzled/plugin/storage_engine.h"
 
 #include <boost/dynamic_bitset.hpp>
 #include <list>

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2011-02-10 01:11:26 +0000
+++ drizzled/statement/alter_table.cc	2011-02-12 10:06:03 +0000
@@ -41,6 +41,8 @@
 #include "drizzled/pthread_globals.h"
 #include "drizzled/internal/my_sys.h"
 #include "drizzled/internal/iocache.h"
+#include "drizzled/plugin/storage_engine.h"
+#include <drizzled/copy_field.h>
 
 #include "drizzled/transaction_services.h"
 

=== modified file 'drizzled/statement/create_index.cc'
--- drizzled/statement/create_index.cc	2011-01-25 05:22:22 +0000
+++ drizzled/statement/create_index.cc	2011-02-09 22:48:12 +0000
@@ -19,11 +19,13 @@
  */
 
 #include "config.h"
+
 #include "drizzled/show.h"
 #include "drizzled/session.h"
 #include "drizzled/statement/create_index.h"
 #include "drizzled/statement/alter_table.h"
 #include "drizzled/db.h"
+#include "drizzled/plugin/storage_engine.h"
 
 namespace drizzled
 {

=== modified file 'drizzled/statement/create_schema.cc'
--- drizzled/statement/create_schema.cc	2011-01-22 18:52:16 +0000
+++ drizzled/statement/create_schema.cc	2011-02-09 22:48:12 +0000
@@ -19,12 +19,14 @@
  */
 
 #include "config.h"
+
 #include <drizzled/show.h>
 #include <drizzled/session.h>
 #include <drizzled/statement/create_schema.h>
 #include <drizzled/db.h>
 #include <drizzled/plugin/event_observer.h>
 #include <drizzled/message.h>
+#include <drizzled/plugin/storage_engine.h>
 
 #include <string>
 

=== modified file 'drizzled/statement/create_table.cc'
--- drizzled/statement/create_table.cc	2011-01-25 00:17:00 +0000
+++ drizzled/statement/create_table.cc	2011-02-09 22:48:12 +0000
@@ -25,6 +25,7 @@
 #include <drizzled/statement/create_table.h>
 #include <drizzled/message.h>
 #include <drizzled/identifier.h>
+#include <drizzled/plugin/storage_engine.h>
 
 #include <iostream>
 

=== modified file 'drizzled/statement/drop_index.cc'
--- drizzled/statement/drop_index.cc	2011-01-22 18:52:16 +0000
+++ drizzled/statement/drop_index.cc	2011-02-09 22:48:12 +0000
@@ -19,11 +19,13 @@
  */
 
 #include "config.h"
+
 #include "drizzled/show.h"
 #include "drizzled/session.h"
 #include "drizzled/statement/drop_index.h"
 #include "drizzled/statement/alter_table.h"
 #include "drizzled/db.h"
+#include "drizzled/plugin/storage_engine.h"
 
 namespace drizzled
 {

=== modified file 'drizzled/statement/flush.cc'
--- drizzled/statement/flush.cc	2011-01-22 07:05:32 +0000
+++ drizzled/statement/flush.cc	2011-02-09 22:48:12 +0000
@@ -19,12 +19,14 @@
  */
 
 #include "config.h"
+
 #include <drizzled/show.h>
 #include <drizzled/session.h>
 #include <drizzled/lock.h>
 #include <drizzled/statement/flush.h>
 #include "drizzled/sql_table.h"
 #include "drizzled/plugin/logging.h"
+#include "drizzled/plugin/storage_engine.h"
 
 namespace drizzled
 {

=== modified file 'drizzled/statement/rename_table.cc'
--- drizzled/statement/rename_table.cc	2011-02-04 08:47:29 +0000
+++ drizzled/statement/rename_table.cc	2011-02-09 22:48:12 +0000
@@ -25,6 +25,7 @@
 #include <drizzled/statement/rename_table.h>
 #include "drizzled/sql_table.h"
 #include "drizzled/pthread_globals.h"
+#include "drizzled/plugin/storage_engine.h"
 
 namespace drizzled
 {

=== modified file 'drizzled/status_helper.cc'
--- drizzled/status_helper.cc	2010-12-18 04:43:40 +0000
+++ drizzled/status_helper.cc	2011-02-09 00:29:59 +0000
@@ -25,6 +25,8 @@
 #include "drizzled/drizzled.h"
 #include "plugin/myisam/myisam.h"
 
+#include <drizzled/refresh_version.h>
+
 #include <sstream>
 
 using namespace std;
@@ -32,7 +34,6 @@
 namespace drizzled
 {
 
-extern uint64_t refresh_version;
 extern time_t server_start_time;
 extern time_t flush_status_time;
 

=== added file 'drizzled/stored_key.cc'
--- drizzled/stored_key.cc	1970-01-01 00:00:00 +0000
+++ drizzled/stored_key.cc	2011-02-12 02:27:23 +0000
@@ -0,0 +1,74 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include <drizzled/field/varstring.h>
+#include <drizzled/session.h>
+#include <drizzled/stored_key.h>
+
+namespace drizzled
+{
+
+StoredKey::StoredKey(Session *session,
+                     Field *field_arg, 
+                     unsigned char *ptr,
+                     unsigned char *null, 
+                     uint32_t length) :
+  null_key(0), 
+  null_ptr(null), 
+  err(0)
+  {
+    if (field_arg->type() == DRIZZLE_TYPE_BLOB)
+    {
+      /*
+        Key segments are always packed with a 2 byte length prefix.
+        See mi_rkey for details.
+      */
+      to_field= new Field_varstring(ptr,
+                                    length,
+                                    2,
+                                    null,
+                                    1,
+                                    field_arg->field_name,
+                                    field_arg->charset());
+      to_field->init(field_arg->getTable());
+    }
+    else
+    {
+      to_field= field_arg->new_key_field(session->mem_root, field_arg->getTable(),
+                                         ptr, null, 1);
+    }
+
+    to_field->setWriteSet();
+  }
+
+StoredKey::store_key_result StoredKey::copy()
+{
+  store_key_result result;
+  Session *session= to_field->getTable()->in_use;
+  enum_check_fields saved_count_cuted_fields= session->count_cuted_fields;
+  session->count_cuted_fields= CHECK_FIELD_IGNORE;
+  result= copy_inner();
+  session->count_cuted_fields= saved_count_cuted_fields;
+
+  return result;
+}
+
+} /* namespace drizzled */

=== modified file 'drizzled/stored_key.h'
--- drizzled/stored_key.h	2010-12-18 04:43:40 +0000
+++ drizzled/stored_key.h	2011-02-12 06:56:00 +0000
@@ -20,9 +20,16 @@
 #ifndef DRIZZLED_STORED_KEY_H
 #define DRIZZLED_STORED_KEY_H
 
+#include <drizzled/memory/sql_alloc.h>
+#include <drizzled/copy_field.h>
+
 namespace drizzled
 {
 
+class Field;
+class Session;
+class Item;
+
 /** class to store an field/item as a key struct */
 class StoredKey :public memory::SqlAlloc
 {
@@ -34,43 +41,20 @@
     STORE_KEY_FATAL, 
     STORE_KEY_CONV 
   };
+
 protected:
   Field *to_field;				// Store data here
   unsigned char *null_ptr;
   unsigned char err;
   virtual enum store_key_result copy_inner()=0;
+
 public:
   StoredKey(Session *session,
             Field *field_arg, 
             unsigned char *ptr,
             unsigned char *null, 
-            uint32_t length)
-    :
-      null_key(0), 
-      null_ptr(null), 
-      err(0)
-  {
-    if (field_arg->type() == DRIZZLE_TYPE_BLOB)
-    {
-      /*
-        Key segments are always packed with a 2 byte length prefix.
-        See mi_rkey for details.
-      */
-      to_field= new Field_varstring(ptr,
-                                    length,
-                                    2,
-                                    null,
-                                    1,
-                                    field_arg->field_name,
-                                    field_arg->charset());
-      to_field->init(field_arg->getTable());
-    }
-    else
-      to_field= field_arg->new_key_field(session->mem_root, field_arg->getTable(),
-                                        ptr, null, 1);
+            uint32_t length);
 
-    to_field->setWriteSet();
-  }
   virtual ~StoredKey() {}			/** Not actually needed */
   virtual const char *name() const=0;
 
@@ -80,31 +64,23 @@
     @details this function makes sure truncation warnings when preparing the
     key buffers don't end up as errors (because of an enclosing INSERT/UPDATE).
   */
-  enum store_key_result copy()
-  {
-    enum store_key_result result;
-    Session *session= to_field->getTable()->in_use;
-    enum_check_fields saved_count_cuted_fields= session->count_cuted_fields;
-    session->count_cuted_fields= CHECK_FIELD_IGNORE;
-    result= copy_inner();
-    session->count_cuted_fields= saved_count_cuted_fields;
+  enum store_key_result copy();
 
-    return result;
-  }
 };
 
 class store_key_field: public StoredKey
 {
   CopyField copy_field;
   const char *field_name;
+
 public:
   store_key_field(Session *session, Field *to_field_arg, unsigned char *ptr,
                   unsigned char *null_ptr_arg,
-		  uint32_t length, Field *from_field, const char *name_arg)
-    :StoredKey(session, to_field_arg,ptr,
-	       null_ptr_arg ? null_ptr_arg : from_field->maybe_null() ? &err
-	       : (unsigned char*) 0, length), field_name(name_arg)
-  {
+                  uint32_t length, Field *from_field, const char *name_arg) :
+    StoredKey(session, to_field_arg,ptr,
+              null_ptr_arg ? null_ptr_arg : from_field->maybe_null() ? &err
+              : (unsigned char*) 0, length), field_name(name_arg)
+    {
     if (to_field)
     {
       copy_field.set(to_field,from_field,0);
@@ -123,12 +99,13 @@
 
 class store_key_item :public StoredKey
 {
- protected:
+protected:
   Item *item;
+
 public:
   store_key_item(Session *session, Field *to_field_arg, unsigned char *ptr,
-                 unsigned char *null_ptr_arg, uint32_t length, Item *item_arg)
-    :StoredKey(session, to_field_arg, ptr,
+                 unsigned char *null_ptr_arg, uint32_t length, Item *item_arg) :
+    StoredKey(session, to_field_arg, ptr,
 	       null_ptr_arg ? null_ptr_arg : item_arg->maybe_null ?
 	       &err : (unsigned char*) 0, length), item(item_arg)
   {}
@@ -146,13 +123,14 @@
 class store_key_const_item :public store_key_item
 {
   bool inited;
+
 public:
   store_key_const_item(Session *session, Field *to_field_arg, unsigned char *ptr,
-		       unsigned char *null_ptr_arg, uint32_t length,
-		       Item *item_arg)
-    :store_key_item(session, to_field_arg,ptr,
-		    null_ptr_arg ? null_ptr_arg : item_arg->maybe_null ?
-		    &err : (unsigned char*) 0, length, item_arg), inited(0)
+                       unsigned char *null_ptr_arg, uint32_t length,
+                       Item *item_arg) :
+    store_key_item(session, to_field_arg,ptr,
+                   null_ptr_arg ? null_ptr_arg : item_arg->maybe_null ?
+                   &err : (unsigned char*) 0, length, item_arg), inited(0)
   {
   }
   const char *name() const { return "const"; }

=== modified file 'drizzled/sys_var.cc'
--- drizzled/sys_var.cc	2011-02-11 16:10:26 +0000
+++ drizzled/sys_var.cc	2011-02-12 10:06:03 +0000
@@ -61,6 +61,7 @@
 #include "drizzled/transaction_services.h"
 #include "drizzled/constrained_value.h"
 #include "drizzled/visibility.h"
+#include "drizzled/plugin/storage_engine.h"
 
 #include <cstdio>
 #include <map>
@@ -1489,7 +1490,7 @@
 drizzle_show_var* enumerate_sys_vars(Session *session)
 {
   int size= sizeof(drizzle_show_var) * (system_variable_map.size() + 1);
-  drizzle_show_var *result= (drizzle_show_var*) session->alloc(size);
+  drizzle_show_var *result= (drizzle_show_var*) session->getMemRoot()->allocate(size);
 
   if (result)
   {

=== added file 'drizzled/system_variables.h'
--- drizzled/system_variables.h	1970-01-01 00:00:00 +0000
+++ drizzled/system_variables.h	2011-02-12 10:06:03 +0000
@@ -0,0 +1,103 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2011 Brian Aker
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_SYSTEM_VARIABLES_H
+#define DRIZZLED_SYSTEM_VARIABLES_H
+
+namespace drizzled
+{
+
+struct drizzle_system_variables
+{
+  drizzle_system_variables()
+  {}
+  /*
+    How dynamically allocated system variables are handled:
+
+    The global_system_variables and max_system_variables are "authoritative"
+    They both should have the same 'version' and 'size'.
+    When attempting to access a dynamic variable, if the session version
+    is out of date, then the session version is updated and realloced if
+    neccessary and bytes copied from global to make up for missing data.
+  */
+  ulong dynamic_variables_version;
+  char * dynamic_variables_ptr;
+  uint32_t dynamic_variables_head;  /* largest valid variable offset */
+  uint32_t dynamic_variables_size;  /* how many bytes are in use */
+
+  uint64_t myisam_max_extra_sort_file_size;
+  uint64_t max_heap_table_size;
+  uint64_t tmp_table_size;
+  ha_rows select_limit;
+  ha_rows max_join_size;
+  uint64_t auto_increment_increment;
+  uint64_t auto_increment_offset;
+  uint64_t bulk_insert_buff_size;
+  uint64_t join_buff_size;
+  uint32_t max_allowed_packet;
+  uint64_t max_error_count;
+  uint64_t max_length_for_sort_data;
+  size_t max_sort_length;
+  uint64_t min_examined_row_limit;
+  bool optimizer_prune_level;
+  bool log_warnings;
+
+  uint32_t optimizer_search_depth;
+  uint32_t div_precincrement;
+  uint64_t preload_buff_size;
+  uint32_t read_buff_size;
+  uint32_t read_rnd_buff_size;
+  bool replicate_query;
+  size_t sortbuff_size;
+  uint32_t thread_handling;
+  uint32_t tx_isolation;
+  uint32_t completion_type;
+  /* Determines which non-standard SQL behaviour should be enabled */
+  uint32_t sql_mode;
+  uint64_t max_seeks_for_key;
+  size_t range_alloc_block_size;
+  uint32_t query_alloc_block_size;
+  uint32_t query_prealloc_size;
+  uint64_t group_concat_max_len;
+  uint64_t pseudo_thread_id;
+
+  plugin::StorageEngine *storage_engine;
+
+  /* Only charset part of these variables is sensible */
+  const CHARSET_INFO  *character_set_filesystem;
+
+  /* Both charset and collation parts of these variables are important */
+  const CHARSET_INFO	*collation_server;
+
+  inline const CHARSET_INFO  *getCollation(void) 
+  {
+    return collation_server;
+  }
+
+  /* Locale Support */
+  MY_LOCALE *lc_time_names;
+
+  Time_zone *time_zone;
+};
+
+
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_SYSTEM_VARIABLES_H */

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2011-02-08 04:42:44 +0000
+++ drizzled/table.cc	2011-02-12 10:06:03 +0000
@@ -46,6 +46,7 @@
 #include "drizzled/charset.h"
 #include "drizzled/internal/m_string.h"
 #include "plugin/myisam/myisam.h"
+#include "drizzled/plugin/storage_engine.h"
 
 #include <drizzled/item/string.h>
 #include <drizzled/item/int.h>
@@ -54,6 +55,8 @@
 #include <drizzled/item/null.h>
 #include <drizzled/temporal.h>
 
+#include <drizzled/refresh_version.h>
+
 #include "drizzled/table/singular.h"
 
 #include "drizzled/table_proto.h"
@@ -1751,4 +1754,22 @@
   }
 }
 
+/*
+  Is this instance of the table should be reopen or represents a name-lock?
+*/
+bool Table::needs_reopen_or_name_lock() const
+{ 
+  return getShare()->getVersion() != refresh_version;
+}
+
+uint32_t Table::index_flags(uint32_t idx) const
+{
+  return getShare()->getEngine()->index_flags(getShare()->getKeyInfo(idx).algorithm);
+}
+
+void Table::print_error(int error, myf errflag) const
+{
+  getShare()->getEngine()->print_error(error, errflag, *this);
+}
+
 } /* namespace drizzled */

=== modified file 'drizzled/table.h'
--- drizzled/table.h	2011-02-04 21:25:07 +0000
+++ drizzled/table.h	2011-02-11 21:34:53 +0000
@@ -44,19 +44,16 @@
 namespace drizzled
 {
 
+class COND_EQUAL;
+class Field_blob;
 class Item;
 class Item_subselect;
+class SecurityContext;
+class Select_Lex;
 class Select_Lex_Unit;
-class Select_Lex;
-class COND_EQUAL;
-class SecurityContext;
 class TableList;
-namespace field {
-class Epoch;
-}
-class Field_blob;
-
-extern uint64_t refresh_version;
+namespace field { class Epoch; }
+namespace plugin { class StorageEngine; }
 
 typedef enum enum_table_category TABLE_CATEGORY;
 typedef struct st_columndef MI_COLUMNDEF;
@@ -68,8 +65,8 @@
 class DRIZZLED_API Table 
 {
   Field **field; /**< Pointer to fields collection */
+
 public:
-
   Field **getFields() const
   {
     return field;
@@ -151,7 +148,7 @@
     return in_use;
   }
 
-  unsigned char *getInsertRecord()
+  unsigned char *getInsertRecord() const
   {
     return record[0];
   }
@@ -428,14 +425,11 @@
   inline bool isDatabaseLowByteFirst() const { return getShare()->db_low_byte_first; } /* Portable row format */
   inline bool isNameLock() const { return open_placeholder; }
 
-  uint32_t index_flags(uint32_t idx) const
-  {
-    return getShare()->storage_engine->index_flags(getShare()->getKeyInfo(idx).algorithm);
-  }
+  uint32_t index_flags(uint32_t idx) const;
 
   inline plugin::StorageEngine *getEngine() const   /* table_type for handler */
   {
-    return getShare()->storage_engine;
+    return getShare()->getEngine();
   }
 
   Cursor &getCursor() const /* table_type for handler */
@@ -561,13 +555,11 @@
   {
     return db_stat || open_placeholder;
   }
+
   /*
     Is this instance of the table should be reopen or represents a name-lock?
   */
-  inline bool needs_reopen_or_name_lock()
-  { 
-    return getShare()->getVersion() != refresh_version;
-  }
+  bool needs_reopen_or_name_lock() const;
 
   /**
     clean/setup table fields and map.
@@ -588,16 +580,13 @@
   void filesort_free_buffers(bool full= false);
   void intern_close_table();
 
-  void print_error(int error, myf errflag)
-  {
-    getShare()->storage_engine->print_error(error, errflag, *this);
-  }
+  void print_error(int error, myf errflag) const;
 
   /**
     @return
     key if error because of duplicated keys
   */
-  uint32_t get_dup_key(int error)
+  uint32_t get_dup_key(int error) const
   {
     cursor->errkey  = (uint32_t) -1;
     if (error == HA_ERR_FOUND_DUPP_KEY || error == HA_ERR_FOREIGN_DUPLICATE_KEY ||
@@ -841,8 +830,6 @@
 namespace optimizer { class SqlSelect; }
 
 void change_double_for_sort(double nr,unsigned char *to);
-double my_double_round(double value, int64_t dec, bool dec_unsigned,
-                       bool truncate);
 int get_quick_record(optimizer::SqlSelect *select);
 
 void find_date(char *pos,uint32_t *vek,uint32_t flag);

=== modified file 'drizzled/table/instance/base.cc'
--- drizzled/table/instance/base.cc	2011-02-05 20:30:22 +0000
+++ drizzled/table/instance/base.cc	2011-02-09 22:48:12 +0000
@@ -81,8 +81,12 @@
 #include "drizzled/field/varstring.h"
 #include "drizzled/field/uuid.h"
 
+#include "drizzled/plugin/storage_engine.h"
+
 #include "drizzled/definition/cache.h"
 
+#include <drizzled/refresh_version.h>
+
 using namespace std;
 
 namespace drizzled
@@ -2042,5 +2046,10 @@
   abort();
 }
 
+void TableShare::refreshVersion()
+{
+  version= refresh_version;
+}
+
 
 } /* namespace drizzled */

=== modified file 'drizzled/table/instance/base.h'
--- drizzled/table/instance/base.h	2011-02-05 10:36:50 +0000
+++ drizzled/table/instance/base.h	2011-02-09 00:29:59 +0000
@@ -50,8 +50,6 @@
 namespace drizzled
 {
 
-extern uint64_t refresh_version;
-
 const static std::string NO_PROTOBUFFER_AVAILABLE("NO PROTOBUFFER AVAILABLE");
 
 namespace plugin
@@ -366,10 +364,7 @@
     return version;
   }
 
-  void refreshVersion()
-  {
-   version= refresh_version;
-  }
+  void refreshVersion();
 
   void resetVersion()
   {

=== modified file 'drizzled/table/singular.cc'
--- drizzled/table/singular.cc	2011-01-17 04:15:23 +0000
+++ drizzled/table/singular.cc	2011-02-08 03:35:42 +0000
@@ -98,7 +98,7 @@
   null_pack_length= (null_count + 7)/8;
   getMutableShare()->setRecordLength(record_length + null_pack_length);
   getMutableShare()->rec_buff_length= ALIGN_SIZE(getMutableShare()->getRecordLength() + 1);
-  record[0]= (unsigned char*)session->alloc(getMutableShare()->rec_buff_length);
+  record[0]= (unsigned char*)session->getMemRoot()->allocate(getMutableShare()->rec_buff_length);
   if (not getInsertRecord())
   {
     throw "Memory allocation failure";

=== modified file 'drizzled/table/unused.cc'
--- drizzled/table/unused.cc	2011-01-29 23:08:49 +0000
+++ drizzled/table/unused.cc	2011-02-09 22:48:12 +0000
@@ -34,6 +34,8 @@
 namespace drizzled
 {
 
+extern uint64_t table_cache_size;
+
 namespace table
 {
 

=== modified file 'drizzled/table_ident.h'
--- drizzled/table_ident.h	2010-12-18 04:43:40 +0000
+++ drizzled/table_ident.h	2011-02-10 22:27:27 +0000
@@ -21,11 +21,16 @@
 #ifndef DRIZZLED_TABLE_IDENT_H
 #define DRIZZLED_TABLE_IDENT_H
 
-#include "drizzled/session.h"
+#include "drizzled/lex_string.h"
+#include "drizzled/memory/sql_alloc.h"
+#include "drizzled/util/test.h"
 
 namespace drizzled
 {
 
+extern char empty_c_string[1];
+extern char internal_table_name[2];
+
 /* Structure for db & table in sql_yacc */
 class Table_ident :public memory::SqlAlloc
 {

=== modified file 'drizzled/table_proto_write.cc'
--- drizzled/table_proto_write.cc	2011-01-25 05:20:15 +0000
+++ drizzled/table_proto_write.cc	2011-02-09 22:48:12 +0000
@@ -21,6 +21,8 @@
 #include "drizzled/global_charset_info.h"
 #include "drizzled/message/statement_transform.h"
 
+#include <drizzled/plugin/storage_engine.h>
+
 #include "drizzled/internal/my_sys.h"
 
 

=== modified file 'drizzled/temporal_interval.h'
--- drizzled/temporal_interval.h	2010-12-25 04:38:28 +0000
+++ drizzled/temporal_interval.h	2011-02-11 21:34:53 +0000
@@ -25,7 +25,8 @@
 #define DRIZZLED_TEMPORAL_INTERVAL_H
 
 /* @TODO Replace this include with some forward decls */
-#include "drizzled/item.h"
+#include <drizzled/item.h>
+#include <drizzled/type/time.h>
 
 namespace drizzled 
 {
@@ -39,34 +40,32 @@
 public:
 
   TemporalInterval(uint32_t in_year,
-      uint32_t in_month,
-      uint32_t in_day,
-      uint32_t in_hour,
-      uint64_t in_minute,
-      uint64_t in_second,
-      uint64_t in_second_part,
-      bool in_neg)
-    :
-      year(in_year),
-      month(in_month),
-      day(in_day),
-      hour(in_hour),
-      minute(in_minute),
-      second(in_second),
-      second_part(in_second_part),
-      neg(in_neg)
+                   uint32_t in_month,
+                   uint32_t in_day,
+                   uint32_t in_hour,
+                   uint64_t in_minute,
+                   uint64_t in_second,
+                   uint64_t in_second_part,
+                   bool in_neg) :
+    year(in_year),
+    month(in_month),
+    day(in_day),
+    hour(in_hour),
+    minute(in_minute),
+    second(in_second),
+    second_part(in_second_part),
+    neg(in_neg)
   {}
 
-  TemporalInterval()
-    :
-      year(0),
-      month(0),
-      day(0),
-      hour(0),
-      minute(0),
-      second(0),
-      second_part(0),
-      neg(false)
+  TemporalInterval() :
+    year(0),
+    month(0),
+    day(0),
+    hour(0),
+    minute(0),
+    second(0),
+    second_part(0),
+    neg(false)
   {}
 
   /**

=== modified file 'drizzled/transaction_services.h'
--- drizzled/transaction_services.h	2011-01-26 19:15:55 +0000
+++ drizzled/transaction_services.h	2011-02-12 05:57:44 +0000
@@ -25,11 +25,11 @@
 #ifndef DRIZZLED_TRANSACTION_SERVICES_H
 #define DRIZZLED_TRANSACTION_SERVICES_H
 
-#include "drizzled/atomics.h"
-#include "drizzled/message/transaction.pb.h"
-#include "drizzled/identifier/table.h"
-#include "drizzled/message/schema.h"
-#include "drizzled/session.h"
+#include <drizzled/atomics.h>
+#include <drizzled/message/transaction.pb.h>
+#include <drizzled/identifier/table.h>
+#include <drizzled/message/schema.h>
+#include <drizzled/session.h>
 
 #include "drizzled/visibility.h"
 
@@ -45,6 +45,7 @@
   class TransactionalStorageEngine;
 }
 
+class Session;
 class NamedSavepoint;
 class Field;
 

=== modified file 'drizzled/type/decimal.h'
--- drizzled/type/decimal.h	2011-02-04 02:14:09 +0000
+++ drizzled/type/decimal.h	2011-02-11 21:34:53 +0000
@@ -456,6 +456,10 @@
   return _decimal_zero;
 }
 
+double my_double_round(double value, int64_t dec, bool dec_unsigned,
+                       bool truncate);
+
+
 #define decimal_zero decimal_zero_const()
 
 } /* namespace drizzled */

=== modified file 'drizzled/tztime.h'
--- drizzled/tztime.h	2011-01-25 05:20:15 +0000
+++ drizzled/tztime.h	2011-02-12 05:57:44 +0000
@@ -21,7 +21,8 @@
 #ifndef DRIZZLED_TZTIME_H
 #define DRIZZLED_TZTIME_H
 
-#include "drizzled/memory/sql_alloc.h"
+#include <drizzled/memory/sql_alloc.h>
+#include <drizzled/type/time.h>
 
 #include "drizzled/type/time.h"
 
@@ -30,10 +31,6 @@
 
 class String;
 
-namespace type {
-class Time;
-}
-
 /**
   This class represents abstract time zone and provides
   basic interface for type::Time <-> type::Time::epoch_t conversion.
@@ -73,8 +70,8 @@
 };
 
 extern Time_zone * my_tz_SYSTEM;
-extern Time_zone * my_tz_find(Session *session, const String *name);
-extern bool     my_tz_init(Session *org_session, const char *default_tzname);
+Time_zone * my_tz_find(Session *session, const String *name);
+bool     my_tz_init(Session *org_session, const char *default_tzname);
 
 } /* namespace drizzled */
 

=== modified file 'drizzled/util/string.h'
--- drizzled/util/string.h	2010-12-18 04:43:40 +0000
+++ drizzled/util/string.h	2011-02-08 22:56:58 +0000
@@ -36,9 +36,13 @@
 #ifndef DRIZZLED_UTIL_STRING_H
 #define DRIZZLED_UTIL_STRING_H
 
+#include <utility>
 #include <string>
+#include <vector>
+
 #include <boost/algorithm/string/predicate.hpp>
 #include <boost/functional/hash.hpp>
+#include <boost/shared_ptr.hpp>
 
 namespace drizzled
 {

=== modified file 'plugin/archive/archive_engine.h'
--- plugin/archive/archive_engine.h	2011-01-17 04:15:23 +0000
+++ plugin/archive/archive_engine.h	2011-02-09 22:48:12 +0000
@@ -22,6 +22,7 @@
 #include <drizzled/thr_lock.h>
 #include <drizzled/my_hash.h>
 #include <drizzled/cursor.h>
+#include <drizzled/plugin/storage_engine.h>
 
 #include <fcntl.h>
 #include <inttypes.h>

=== modified file 'plugin/ascii/ascii.cc'
--- plugin/ascii/ascii.cc	2011-01-17 18:16:53 +0000
+++ plugin/ascii/ascii.cc	2011-02-09 22:48:12 +0000
@@ -18,6 +18,8 @@
  */
 
 #include "config.h"
+
+#include <drizzled/plugin.h>
 #include <drizzled/function/math/int.h>
 #include <drizzled/plugin/function.h>
 

=== modified file 'plugin/blackhole/ha_blackhole.cc'
--- plugin/blackhole/ha_blackhole.cc	2011-01-17 18:16:53 +0000
+++ plugin/blackhole/ha_blackhole.cc	2011-02-09 22:48:12 +0000
@@ -14,22 +14,26 @@
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 #include "config.h"
+
+#include <drizzled/error.h>
+#include <drizzled/global_charset_info.h>
+#include <drizzled/internal/m_string.h>
+#include <drizzled/internal/my_pthread.h>
+#include <drizzled/message/table.h>
+#include <drizzled/plugin/storage_engine.h>
 #include <drizzled/table.h>
-#include <drizzled/error.h>
-#include "drizzled/internal/my_pthread.h"
+
 
 #include "ha_blackhole.h"
 
 #include <fcntl.h>
 
+#include <fstream>
+#include <map>
 #include <string>
-#include <map>
-#include <fstream>
-#include <drizzled/message/table.pb.h>
-#include "drizzled/internal/m_string.h"
+
 #include <google/protobuf/io/zero_copy_stream.h>
 #include <google/protobuf/io/zero_copy_stream_impl.h>
-#include "drizzled/global_charset_info.h"
 
 
 using namespace std;

=== modified file 'plugin/blitzdb/ha_blitz.cc'
--- plugin/blitzdb/ha_blitz.cc	2011-02-10 00:46:02 +0000
+++ plugin/blitzdb/ha_blitz.cc	2011-02-12 10:06:03 +0000
@@ -18,7 +18,9 @@
  */
 
 #include "config.h"
+
 #include "ha_blitz.h"
+#include <drizzled/plugin/storage_engine.h>
 
 using namespace std;
 using namespace drizzled;

=== modified file 'plugin/charlength/charlength.cc'
--- plugin/charlength/charlength.cc	2011-01-17 18:16:53 +0000
+++ plugin/charlength/charlength.cc	2011-02-09 22:48:12 +0000
@@ -18,7 +18,9 @@
  */
 
 #include "config.h"
+
 #include <drizzled/function/math/int.h>
+#include <drizzled/plugin.h>
 #include <drizzled/plugin/function.h>
 
 using namespace std;

=== modified file 'plugin/crc32/crc32udf.cc'
--- plugin/crc32/crc32udf.cc	2010-12-18 04:43:40 +0000
+++ plugin/crc32/crc32udf.cc	2011-02-09 22:48:12 +0000
@@ -18,6 +18,8 @@
  */
 
 #include "config.h"
+
+#include <drizzled/plugin.h>
 #include <drizzled/plugin/function.h>
 #include <drizzled/item/func.h>
 #include <drizzled/algorithm/crc32.h>

=== modified file 'plugin/debug/module.cc'
--- plugin/debug/module.cc	2011-01-17 18:16:53 +0000
+++ plugin/debug/module.cc	2011-02-12 08:10:17 +0000
@@ -38,10 +38,11 @@
 
 #include <signal.h>
 
-#include <drizzled/util/backtrace.h>
 #include <drizzled/function/func.h>
 #include <drizzled/item/cmpfunc.h>
 #include <drizzled/item/function/boolean.h>
+#include <drizzled/plugin/function.h>
+#include <drizzled/util/backtrace.h>
 
 using namespace drizzled;
 

=== modified file 'plugin/haildb/haildb_datadict_dump_func.h'
--- plugin/haildb/haildb_datadict_dump_func.h	2010-09-23 05:02:37 +0000
+++ plugin/haildb/haildb_datadict_dump_func.h	2011-02-09 22:48:12 +0000
@@ -19,6 +19,8 @@
 #ifndef PLUGIN_HAILDB_HAILDB_DATADICT_DUMP_FUNC_H
 #define PLUGIN_HAILDB_HAILDB_DATADICT_DUMP_FUNC_H
 
+#include <drizzled/plugin/storage_engine.h>
+
 int haildb_datadict_dump_func_initialize(drizzled::module::Context &context);
 
 #endif /* PLUGIN_HAILDB_HAILDB_DATADICT_DUMP_FUNC_H */

=== modified file 'plugin/hello_world/hello_world.cc'
--- plugin/hello_world/hello_world.cc	2011-01-17 18:16:53 +0000
+++ plugin/hello_world/hello_world.cc	2011-02-09 22:48:12 +0000
@@ -18,9 +18,11 @@
  */
 
 #include "config.h"
+
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
+#include <drizzled/plugin.h>
 #include <drizzled/plugin/function.h>
-#include <drizzled/item/func.h>
-#include <drizzled/function/str/strfunc.h>
 
 #include <string>
 

=== modified file 'plugin/hex_functions/hex_functions.cc'
--- plugin/hex_functions/hex_functions.cc	2011-01-17 18:16:53 +0000
+++ plugin/hex_functions/hex_functions.cc	2011-02-11 21:34:53 +0000
@@ -18,11 +18,12 @@
  */
 
 #include "config.h"
+
+#include <drizzled/charset_info.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/internal/m_string.h>
+#include <drizzled/plugin/function.h>
 #include <drizzled/util/convert.h>
-#include "drizzled/internal/m_string.h"
-
-#include <drizzled/plugin/function.h>
-#include <drizzled/function/str/strfunc.h>
 
 using namespace drizzled;
 

=== modified file 'plugin/information_schema_dictionary/domains.cc'
--- plugin/information_schema_dictionary/domains.cc	2010-03-17 19:18:40 +0000
+++ plugin/information_schema_dictionary/domains.cc	2011-02-10 22:27:27 +0000
@@ -19,6 +19,7 @@
  */
 
 #include "config.h"
+
 #include "plugin/information_schema_dictionary/dictionary.h"
 
 using namespace std;

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2011-02-11 16:10:26 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2011-02-12 10:06:03 +0000
@@ -466,7 +466,7 @@
   UNIV_INTERN int doRenameTable(Session&, const identifier::Table &from, const identifier::Table &to);
   UNIV_INTERN int doDropTable(Session &session, const identifier::Table &identifier);
 
-  UNIV_INTERN virtual bool get_error_message(int error, String *buf);
+  UNIV_INTERN virtual bool get_error_message(int error, String *buf) const;
 
   UNIV_INTERN uint32_t max_supported_keys() const;
   UNIV_INTERN uint32_t max_supported_key_length() const;
@@ -7759,7 +7759,7 @@
                               tmp_foreign_fields, tmp_referenced_fields);
 
     ForeignKeyInfo *pf_key_info = (ForeignKeyInfo *)
-      session->memdup(&f_key_info, sizeof(ForeignKeyInfo));
+      session->getMemRoot()->duplicate(&f_key_info, sizeof(ForeignKeyInfo));
     f_key_list->push_back(pf_key_info);
     foreign = UT_LIST_GET_NEXT(foreign_list, foreign);
   }
@@ -8703,7 +8703,7 @@
 /* See comment in Cursor.cc */
 UNIV_INTERN
 bool
-InnobaseEngine::get_error_message(int, String *buf)
+InnobaseEngine::get_error_message(int, String *buf) const
 {
   trx_t*  trx = check_trx_exists(current_session);
 

=== modified file 'plugin/math_functions/abs.cc'
--- plugin/math_functions/abs.cc	2010-12-25 01:27:46 +0000
+++ plugin/math_functions/abs.cc	2011-02-11 21:34:53 +0000
@@ -18,8 +18,10 @@
  */
 
 #include "config.h"
+
 #include <math.h>
 #include "abs.h"
+#include <drizzled/type/decimal.h>
 
 namespace drizzled
 {

=== modified file 'plugin/math_functions/ceiling.cc'
--- plugin/math_functions/ceiling.cc	2010-12-26 08:07:57 +0000
+++ plugin/math_functions/ceiling.cc	2011-02-11 21:34:53 +0000
@@ -20,6 +20,7 @@
 #include "config.h"
 #include <math.h>
 #include "ceiling.h"
+#include <drizzled/type/decimal.h>
 
 namespace drizzled
 {

=== modified file 'plugin/math_functions/floor.cc'
--- plugin/math_functions/floor.cc	2010-12-26 08:07:57 +0000
+++ plugin/math_functions/floor.cc	2011-02-11 21:34:53 +0000
@@ -21,6 +21,8 @@
 #include <math.h>
 #include "floor.h"
 
+#include <drizzled/type/decimal.h>
+
 namespace drizzled
 {
 

=== modified file 'plugin/math_functions/ord.cc'
--- plugin/math_functions/ord.cc	2010-12-18 04:43:40 +0000
+++ plugin/math_functions/ord.cc	2011-02-11 21:34:53 +0000
@@ -21,6 +21,9 @@
 
 #include "ord.h"
 
+#include <drizzled/charset_info.h>
+#include <drizzled/type/decimal.h>
+
 namespace drizzled
 {
 

=== modified file 'plugin/md5/md5.cc'
--- plugin/md5/md5.cc	2011-02-01 02:51:01 +0000
+++ plugin/md5/md5.cc	2011-02-11 21:34:53 +0000
@@ -21,10 +21,11 @@
 
 #include <gcrypt.h>
 
+#include <drizzled/charset.h>
+#include <drizzled/charset_info.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
 #include <drizzled/plugin/function.h>
-#include <drizzled/item/func.h>
-#include "drizzled/charset.h"
-#include <drizzled/function/str/strfunc.h>
 
 using namespace std;
 using namespace drizzled;

=== modified file 'plugin/memory/ha_heap.cc'
--- plugin/memory/ha_heap.cc	2011-01-17 18:16:53 +0000
+++ plugin/memory/ha_heap.cc	2011-02-09 22:48:12 +0000
@@ -18,7 +18,8 @@
 #include <drizzled/table.h>
 #include <drizzled/session.h>
 #include <drizzled/field/varstring.h>
-#include "drizzled/plugin/daemon.h"
+#include <drizzled/plugin/daemon.h>
+#include <drizzled/plugin/storage_engine.h>
 
 #include <boost/thread/mutex.hpp>
 

=== modified file 'plugin/myisam/ha_myisam.cc'
--- plugin/myisam/ha_myisam.cc	2011-02-02 17:37:40 +0000
+++ plugin/myisam/ha_myisam.cc	2011-02-09 22:48:12 +0000
@@ -34,6 +34,8 @@
 #include "drizzled/memory/multi_malloc.h"
 #include "drizzled/plugin/daemon.h"
 
+#include <drizzled/plugin/storage_engine.h>
+
 #include <boost/algorithm/string.hpp>
 #include <boost/scoped_ptr.hpp>
 

=== modified file 'plugin/pbms/src/events_ms.cc'
--- plugin/pbms/src/events_ms.cc	2010-12-16 21:42:18 +0000
+++ plugin/pbms/src/events_ms.cc	2011-02-08 03:35:42 +0000
@@ -227,7 +227,7 @@
 		
 		if (length > org_length) {
 			// This can only happen if the BLOB URL is actually larger than the BLOB itself.
-			blob = (char *) session.alloc(length);
+			blob = (char *) session.getMemRoot()->allocate(length);
 			memcpy(blob_rec+packlength, &blob, sizeof(char*));
 		}			
 		memcpy(blob, blob_url_buffer.bu_data, length);

=== modified file 'plugin/reverse_function/reverse_function.cc'
--- plugin/reverse_function/reverse_function.cc	2011-01-17 18:16:53 +0000
+++ plugin/reverse_function/reverse_function.cc	2011-02-11 21:34:53 +0000
@@ -22,6 +22,7 @@
 
 #include <drizzled/plugin/function.h>
 #include <drizzled/function/str/strfunc.h>
+#include <drizzled/charset_info.h>
 
 using namespace drizzled;
 

=== modified file 'plugin/session_dictionary/processlist.cc'
--- plugin/session_dictionary/processlist.cc	2011-01-26 19:15:55 +0000
+++ plugin/session_dictionary/processlist.cc	2011-02-07 17:58:52 +0000
@@ -65,7 +65,7 @@
 
   while ((tmp= session_generator))
   {
-    drizzled::Session::State::const_shared_ptr state(tmp->state());
+    drizzled::session::State::const_shared_ptr state(tmp->state());
     identifier::User::const_shared_ptr tmp_sctx= tmp->user();
 
     /* ID */

=== modified file 'plugin/show_schema_proto/show_schema_proto.cc'
--- plugin/show_schema_proto/show_schema_proto.cc	2011-01-17 18:16:53 +0000
+++ plugin/show_schema_proto/show_schema_proto.cc	2011-02-09 22:48:12 +0000
@@ -15,19 +15,22 @@
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 #include "config.h"
-#include <drizzled/plugin/function.h>
-#include <drizzled/item/func.h>
-#include <drizzled/function/str/strfunc.h>
-#include <drizzled/error.h>
+
+#include <drizzled/charset.h>
 #include <drizzled/current_session.h>
 #include <drizzled/db.h>
-#include "drizzled/charset.h"
-#include "drizzled/internal/my_sys.h"
+#include <drizzled/error.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/internal/my_sys.h>
+#include <drizzled/item/func.h>
+#include <drizzled/message/schema.h>
+#include <drizzled/plugin/function.h>
+#include <drizzled/plugin/storage_engine.h>
 
+#include <iostream>
 #include <stdio.h>
-#include <iostream>
 #include <string>
-#include <drizzled/message/schema.pb.h>
+
 #include <google/protobuf/io/zero_copy_stream.h>
 #include <google/protobuf/io/zero_copy_stream_impl.h>
 #include <google/protobuf/text_format.h>

=== modified file 'plugin/signal_handler/signal_handler.cc'
--- plugin/signal_handler/signal_handler.cc	2011-02-01 02:51:01 +0000
+++ plugin/signal_handler/signal_handler.cc	2011-02-09 00:29:59 +0000
@@ -1,4 +1,6 @@
-/* Copyright (C) 2006 MySQL AB
+/* 
+   Copyright (C) 2011 Brian Aker
+   Copyright (C) 2006 MySQL AB
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -14,23 +16,26 @@
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
 #include "config.h"
+
 #include <drizzled/gettext.h>
 #include <drizzled/error.h>
 #include <drizzled/unireg.h>
 #include <drizzled/plugin/storage_engine.h>
-#include <drizzled/cursor.h> /* for refresh_version */
 #include "drizzled/pthread_globals.h"
 #include "drizzled/internal/my_pthread.h"
 #include "drizzled/internal/my_sys.h"
 #include "drizzled/plugin/daemon.h"
 #include "drizzled/signal_handler.h"
 
-#include "drizzled/session/cache.h"
+#include <drizzled/session.h>
+#include <drizzled/session/cache.h>
 
 #include "drizzled/debug.h"
 
 #include "drizzled/drizzled.h"
 
+#include <drizzled/refresh_version.h>
+
 #include <boost/thread/thread.hpp>
 #include <boost/filesystem.hpp>
 

=== modified file 'plugin/string_functions/format.cc'
--- plugin/string_functions/format.cc	2011-02-04 02:14:09 +0000
+++ plugin/string_functions/format.cc	2011-02-11 21:34:53 +0000
@@ -22,6 +22,10 @@
 
 #include <limits>
 
+#include <drizzled/charset_info.h>
+#include <drizzled/type/decimal.h>
+#include <drizzled/table.h>
+
 using namespace std;
 
 namespace drizzled

=== modified file 'plugin/string_functions/functions.cc'
--- plugin/string_functions/functions.cc	2010-12-07 21:33:25 +0000
+++ plugin/string_functions/functions.cc	2011-02-09 22:48:12 +0000
@@ -20,6 +20,8 @@
  */
 
 #include "config.h"
+
+#include <drizzled/plugin.h>
 #include "plugin/string_functions/functions.h"
 
 using namespace drizzled;

=== modified file 'plugin/string_functions/functions.h'
--- plugin/string_functions/functions.h	2010-12-07 21:33:25 +0000
+++ plugin/string_functions/functions.h	2011-02-09 22:48:12 +0000
@@ -22,6 +22,7 @@
 #define PLUGIN_STRING_FUNCTIONS_FUNCTIONS_H
 
 #include "drizzled/plugin/function.h"
+
 #include "plugin/string_functions/elt.h"
 #include "plugin/string_functions/format.h"
 #include "plugin/string_functions/quote.h"

=== modified file 'plugin/string_functions/quote.cc'
--- plugin/string_functions/quote.cc	2010-12-18 04:43:40 +0000
+++ plugin/string_functions/quote.cc	2011-02-11 21:34:53 +0000
@@ -21,6 +21,8 @@
 
 #include "quote.h"
 
+#include <drizzled/lex_string.h>
+
 namespace drizzled
 {
 

=== modified file 'plugin/substr_functions/substr_functions.cc'
--- plugin/substr_functions/substr_functions.cc	2011-01-17 18:16:53 +0000
+++ plugin/substr_functions/substr_functions.cc	2011-02-11 21:34:53 +0000
@@ -20,14 +20,15 @@
 
 #include "config.h"
 
+#include <algorithm>
+
+#include <drizzled/charset_info.h>
+#include <drizzled/function/str/strfunc.h>
 #include <drizzled/plugin/function.h>
-#include <algorithm>
 
 using namespace std;
 using namespace drizzled;
 
-#include <drizzled/function/str/strfunc.h>
-
 class SubstrFunction :public Item_str_func
 {
   String tmp_value;

=== modified file 'plugin/tableprototester/tableprototester.cc'
--- plugin/tableprototester/tableprototester.cc	2011-01-17 18:16:53 +0000
+++ plugin/tableprototester/tableprototester.cc	2011-02-09 22:48:12 +0000
@@ -17,9 +17,6 @@
 */
 
 #include "config.h"
-#include <drizzled/table.h>
-#include <drizzled/error.h>
-#include "drizzled/internal/my_pthread.h"
 
 #include "tableprototester.h"
 
@@ -28,10 +25,14 @@
 #include <string>
 #include <map>
 #include <fstream>
-#include <drizzled/message/table.pb.h>
-#include "drizzled/internal/m_string.h"
 
-#include "drizzled/global_charset_info.h"
+#include <drizzled/error.h>
+#include <drizzled/global_charset_info.h>
+#include <drizzled/internal/m_string.h>
+#include <drizzled/internal/my_pthread.h>
+#include <drizzled/message/table.h>
+#include <drizzled/plugin/storage_engine.h>
+#include <drizzled/table.h>
 
 
 using namespace std;

=== modified file 'plugin/transaction_log/hexdump_transaction_message.cc'
--- plugin/transaction_log/hexdump_transaction_message.cc	2011-02-01 02:51:01 +0000
+++ plugin/transaction_log/hexdump_transaction_message.cc	2011-02-09 22:48:12 +0000
@@ -36,6 +36,8 @@
 #include <drizzled/algorithm/crc32.h>
 #include "drizzled/internal/my_sys.h"
 #include "drizzled/charset.h"
+#include <drizzled/errmsg_print.h>
+#include <drizzled/gettext.h>
 
 #include <fcntl.h>
 #include <errno.h>

=== modified file 'plugin/transaction_log/print_transaction_message.cc'
--- plugin/transaction_log/print_transaction_message.cc	2011-02-01 02:51:01 +0000
+++ plugin/transaction_log/print_transaction_message.cc	2011-02-09 22:48:12 +0000
@@ -35,6 +35,8 @@
 #include <drizzled/error.h>
 #include "drizzled/internal/my_sys.h"
 #include "drizzled/charset.h"
+#include <drizzled/gettext.h>
+#include <drizzled/errmsg_print.h>
 
 #include <fcntl.h>
 #include <errno.h>

=== modified file 'plugin/utility_functions/catalog.h'
--- plugin/utility_functions/catalog.h	2010-10-21 08:55:44 +0000
+++ plugin/utility_functions/catalog.h	2011-02-11 21:34:53 +0000
@@ -21,7 +21,9 @@
 #ifndef PLUGIN_UTILITY_FUNCTIONS_CATALOG_H
 #define PLUGIN_UTILITY_FUNCTIONS_CATALOG_H
 
+#include <drizzled/charset_info.h>
 #include <drizzled/function/str/strfunc.h>
+#include <drizzled/global_charset_info.h>
 
 namespace drizzled
 {

=== modified file 'plugin/utility_functions/functions.cc'
--- plugin/utility_functions/functions.cc	2010-12-30 06:23:25 +0000
+++ plugin/utility_functions/functions.cc	2011-02-09 22:48:12 +0000
@@ -20,6 +20,8 @@
  */
 
 #include "config.h"
+
+#include <drizzled/plugin.h>
 #include "plugin/utility_functions/functions.h"
 
 using namespace drizzled;

=== modified file 'plugin/uuid_function/uuid_function.cc'
--- plugin/uuid_function/uuid_function.cc	2011-01-17 18:16:53 +0000
+++ plugin/uuid_function/uuid_function.cc	2011-02-11 21:34:53 +0000
@@ -19,9 +19,12 @@
  */
 
 #include "config.h"
+
+#include <drizzled/charset_info.h>
+#include <drizzled/function/str/strfunc.h>
+#include <drizzled/item/func.h>
 #include <drizzled/plugin/function.h>
-#include <drizzled/item/func.h>
-#include <drizzled/function/str/strfunc.h>
+
 #include <uuid/uuid.h>
 
 #define UUID_LENGTH (8+1+4+1+4+1+4+1+12)

